Merge "Bug 525378 - [PapyrusReq] Add migration of Requirements from SysML 1.4 model to PapyrusRE model"
diff --git a/plugins/sysml14/org.eclipse.papyrus.requirements.sysml14.papyrusre.modellibrary/resources/modellibrary/PapyrusRE_StandardUtils.modellibrary.genmodel b/plugins/sysml14/org.eclipse.papyrus.requirements.sysml14.papyrusre.modellibrary/resources/modellibrary/PapyrusRE_StandardUtils.modellibrary.genmodel
index 7b0b053..700dba5 100644
--- a/plugins/sysml14/org.eclipse.papyrus.requirements.sysml14.papyrusre.modellibrary/resources/modellibrary/PapyrusRE_StandardUtils.modellibrary.genmodel
+++ b/plugins/sysml14/org.eclipse.papyrus.requirements.sysml14.papyrusre.modellibrary/resources/modellibrary/PapyrusRE_StandardUtils.modellibrary.genmodel
@@ -126,7 +126,7 @@
         basePackage="org.eclipse.papyrus.requirements.sysml14.papyrusre.modellibrary.papyrusrestandardutils"
         disposableProviderFactory="true" ecorePackage="papyrusrestandardutils.ecore#//requirementandprocessconcerns">
       <genEnums xsi:type="genmodel:GenEnum" typeSafeEnumCompatible="false" ecoreEnum="papyrusrestandardutils.ecore#//requirementandprocessconcerns/AgreementStatusKind">
-        <genEnumLiterals xsi:type="genmodel:GenEnumLiteral" ecoreEnumLiteral="papyrusrestandardutils.ecore#//requirementandprocessconcerns/AgreementStatusKind/Proposed"/>
+        <genEnumLiterals xsi:type="genmodel:GenEnumLiteral" ecoreEnumLiteral="papyrusrestandardutils.ecore#//requirementandprocessconcerns/AgreementStatusKind/Submitted"/>
         <genEnumLiterals xsi:type="genmodel:GenEnumLiteral" ecoreEnumLiteral="papyrusrestandardutils.ecore#//requirementandprocessconcerns/AgreementStatusKind/ToBeRefined"/>
         <genEnumLiterals xsi:type="genmodel:GenEnumLiteral" ecoreEnumLiteral="papyrusrestandardutils.ecore#//requirementandprocessconcerns/AgreementStatusKind/Accepted"/>
         <genEnumLiterals xsi:type="genmodel:GenEnumLiteral" ecoreEnumLiteral="papyrusrestandardutils.ecore#//requirementandprocessconcerns/AgreementStatusKind/Draft"/>
diff --git a/plugins/sysml14/org.eclipse.papyrus.requirements.sysml14.papyrusre.modellibrary/resources/modellibrary/PapyrusRE_StandardUtils.modellibrary.uml b/plugins/sysml14/org.eclipse.papyrus.requirements.sysml14.papyrusre.modellibrary/resources/modellibrary/PapyrusRE_StandardUtils.modellibrary.uml
index 5e8a2d3..2f3dbdb 100644
--- a/plugins/sysml14/org.eclipse.papyrus.requirements.sysml14.papyrusre.modellibrary/resources/modellibrary/PapyrusRE_StandardUtils.modellibrary.uml
+++ b/plugins/sysml14/org.eclipse.papyrus.requirements.sysml14.papyrusre.modellibrary/resources/modellibrary/PapyrusRE_StandardUtils.modellibrary.uml
@@ -80,7 +80,7 @@
     </packagedElement>
     <packagedElement xmi:type="uml:Package" xmi:id="_jGcj8FOfEeCXkoFpHlFAkw" name="RequirementAndProcessConcerns">
       <packagedElement xmi:type="uml:Enumeration" xmi:id="_ZUhvYFPKEeCXkoFpHlFAkw" name="AgreementStatusKind">
-        <ownedLiteral xmi:type="uml:EnumerationLiteral" xmi:id="_c7L3kFPLEeCXkoFpHlFAkw" name="Proposed"/>
+        <ownedLiteral xmi:type="uml:EnumerationLiteral" xmi:id="_c7L3kFPLEeCXkoFpHlFAkw" name="Submitted"/>
         <ownedLiteral xmi:type="uml:EnumerationLiteral" xmi:id="_dLIYEFPLEeCXkoFpHlFAkw" name="ToBeRefined"/>
         <ownedLiteral xmi:type="uml:EnumerationLiteral" xmi:id="_daLgsFPLEeCXkoFpHlFAkw" name="Accepted"/>
         <ownedLiteral xmi:type="uml:EnumerationLiteral" xmi:id="_KAfiQJMOEeeXis3ri3jkBA" name="Draft"/>
diff --git a/plugins/sysml14/org.eclipse.papyrus.requirements.sysml14.papyrusre.modellibrary/resources/modellibrary/papyrusrestandardutils.ecore b/plugins/sysml14/org.eclipse.papyrus.requirements.sysml14.papyrusre.modellibrary/resources/modellibrary/papyrusrestandardutils.ecore
index b03b14d..e630511 100644
--- a/plugins/sysml14/org.eclipse.papyrus.requirements.sysml14.papyrusre.modellibrary/resources/modellibrary/papyrusrestandardutils.ecore
+++ b/plugins/sysml14/org.eclipse.papyrus.requirements.sysml14.papyrusre.modellibrary/resources/modellibrary/papyrusrestandardutils.ecore
@@ -140,7 +140,7 @@
       <details key="originalName" value="RequirementAndProcessConcerns"/>
     </eAnnotations>
     <eClassifiers xsi:type="ecore:EEnum" name="AgreementStatusKind">
-      <eLiterals name="Proposed"/>
+      <eLiterals name="Submitted"/>
       <eLiterals name="ToBeRefined" value="1"/>
       <eLiterals name="Accepted" value="2"/>
       <eLiterals name="Draft" value="3"/>
diff --git a/plugins/sysml14/org.eclipse.papyrus.requirements.sysml14.papyrusre.modellibrary/src-gen/org/eclipse/papyrus/requirements/sysml14/papyrusre/modellibrary/papyrusrestandardutils/requirementandprocessconcerns/impl/RequirementAndProcessConcernsPackageImpl.java b/plugins/sysml14/org.eclipse.papyrus.requirements.sysml14.papyrusre.modellibrary/src-gen/org/eclipse/papyrus/requirements/sysml14/papyrusre/modellibrary/papyrusrestandardutils/requirementandprocessconcerns/impl/RequirementAndProcessConcernsPackageImpl.java
index c74663b..2fece4a 100644
--- a/plugins/sysml14/org.eclipse.papyrus.requirements.sysml14.papyrusre.modellibrary/src-gen/org/eclipse/papyrus/requirements/sysml14/papyrusre/modellibrary/papyrusrestandardutils/requirementandprocessconcerns/impl/RequirementAndProcessConcernsPackageImpl.java
+++ b/plugins/sysml14/org.eclipse.papyrus.requirements.sysml14.papyrusre.modellibrary/src-gen/org/eclipse/papyrus/requirements/sysml14/papyrusre/modellibrary/papyrusrestandardutils/requirementandprocessconcerns/impl/RequirementAndProcessConcernsPackageImpl.java
@@ -246,7 +246,7 @@
 
 		// Initialize enums and add enum literals
 		initEEnum(agreementStatusKindEEnum, AgreementStatusKind.class, "AgreementStatusKind"); //$NON-NLS-1$
-		addEEnumLiteral(agreementStatusKindEEnum, AgreementStatusKind.PROPOSED);
+		addEEnumLiteral(agreementStatusKindEEnum, AgreementStatusKind.SUBMITTED);
 		addEEnumLiteral(agreementStatusKindEEnum, AgreementStatusKind.TO_BE_REFINED);
 		addEEnumLiteral(agreementStatusKindEEnum, AgreementStatusKind.ACCEPTED);
 		addEEnumLiteral(agreementStatusKindEEnum, AgreementStatusKind.DRAFT);
diff --git a/plugins/sysml14/org.eclipse.papyrus.requirements.sysml14.papyrusre/META-INF/MANIFEST.MF b/plugins/sysml14/org.eclipse.papyrus.requirements.sysml14.papyrusre/META-INF/MANIFEST.MF
index b06310f..de47933 100644
--- a/plugins/sysml14/org.eclipse.papyrus.requirements.sysml14.papyrusre/META-INF/MANIFEST.MF
+++ b/plugins/sysml14/org.eclipse.papyrus.requirements.sysml14.papyrusre/META-INF/MANIFEST.MF
@@ -16,6 +16,8 @@
 Bundle-RequiredExecutionEnvironment: JavaSE-1.8
 Bundle-ActivationPolicy: lazy
 Export-Package: org.eclipse.papyrus.requirements.sysml14.papyrusre.set,
+ org.eclipse.papyrus.requirements.sysml14.papyrusre,
+ org.eclipse.papyrus.requirements.sysml14.papyrusre.impl,
  org.eclipse.papyrus.requirements.sysml14.papyrusre.requirementclassification,
  org.eclipse.papyrus.requirements.sysml14.papyrusre.requirementclassification.impl,
  org.eclipse.papyrus.requirements.sysml14.papyrusre.requirementclassification.util,
diff --git a/plugins/sysml14/org.eclipse.papyrus.requirements.sysml14.papyrusre/resources/profile/PapyrusRE.profile.uml b/plugins/sysml14/org.eclipse.papyrus.requirements.sysml14.papyrusre/resources/profile/PapyrusRE.profile.uml
index cdbdb8d..3ac74ab 100644
--- a/plugins/sysml14/org.eclipse.papyrus.requirements.sysml14.papyrusre/resources/profile/PapyrusRE.profile.uml
+++ b/plugins/sysml14/org.eclipse.papyrus.requirements.sysml14.papyrusre/resources/profile/PapyrusRE.profile.uml
@@ -1,49 +1,34 @@
 <?xml version="1.0" encoding="UTF-8"?>
 <xmi:XMI xmi:version="20131001" xmlns:xmi="http://www.omg.org/spec/XMI/20131001" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:Ecore="http://www.eclipse.org/uml2/schemas/Ecore/5" xmlns:ecore="http://www.eclipse.org/emf/2002/Ecore" xmlns:uml="http://www.eclipse.org/uml2/5.0.0/UML" xsi:schemaLocation="http://www.eclipse.org/uml2/schemas/Ecore/5 pathmap://UML_PROFILES/Ecore.profile.uml#_z1OFcHjqEdy8S4Cr8Rc_NA">
   <uml:Profile xmi:id="_wJDIkDp6EeCmwNGSFJpOjg" name="PapyrusRE">
-    <eAnnotations xmi:type="ecore:EAnnotation" xmi:id="_u2lVoKToEeenne7APpWiQg" source="http://www.eclipse.org/uml2/2.0.0/UML">
-      <contents xmi:type="ecore:EPackage" xmi:id="_u2nx4KToEeenne7APpWiQg" name="papyrusre" nsURI="http://www.eclipse.org/papyrus/requirements/sysml14/0.7.0/PapyrusRE" nsPrefix="PapyrusRE">
-        <eAnnotations xmi:type="ecore:EAnnotation" xmi:id="_u2nx4aToEeenne7APpWiQg" source="http://www.eclipse.org/uml2/4.0.0/UML" references="_6-xDADp8EeCmwNGSFJpOjg"/>
-        <eAnnotations xmi:type="ecore:EAnnotation" xmi:id="_u2nx4qToEeenne7APpWiQg" source="http://www.eclipse.org/uml2/2.0.0/UML">
-          <details xmi:type="ecore:EStringToStringMapEntry" xmi:id="_u2nx46ToEeenne7APpWiQg" key="originalName" value="PapyrusRE"/>
-        </eAnnotations>
-        <eAnnotations xmi:type="ecore:EAnnotation" xmi:id="_u243oKToEeenne7APpWiQg" source="PapyrusVersion">
-          <details xmi:type="ecore:EStringToStringMapEntry" xmi:id="_u243oaToEeenne7APpWiQg" key="Version" value="0.0.1"/>
-          <details xmi:type="ecore:EStringToStringMapEntry" xmi:id="_u243oqToEeenne7APpWiQg" key="Comment" value=""/>
-          <details xmi:type="ecore:EStringToStringMapEntry" xmi:id="_u243o6ToEeenne7APpWiQg" key="Copyright" value=""/>
-          <details xmi:type="ecore:EStringToStringMapEntry" xmi:id="_u243pKToEeenne7APpWiQg" key="Date" value="2017-09-29"/>
-          <details xmi:type="ecore:EStringToStringMapEntry" xmi:id="_u243paToEeenne7APpWiQg" key="Author" value=""/>
-        </eAnnotations>
-      </contents>
-    </eAnnotations>
-    <packageImport xmi:type="uml:PackageImport" xmi:id="_I4Rq8JInEeeji413eaUmIg">
+    <packageImport xmi:id="_I4Rq8JInEeeji413eaUmIg">
       <importedPackage xmi:type="uml:Profile" href="pathmap://SysML14_PROFILES/SysML.profile.uml#SysML.package_packagedElement_Requirements"/>
     </packageImport>
-    <packageImport xmi:type="uml:PackageImport" xmi:id="_I4Rq8ZInEeeji413eaUmIg">
+    <packageImport xmi:id="_I4Rq8ZInEeeji413eaUmIg">
       <importedPackage xmi:type="uml:Profile" href="pathmap://SysML14_PROFILES/SysML.profile.uml#SysML.package_packagedElement_ModelElements"/>
     </packageImport>
-    <packageImport xmi:type="uml:PackageImport" xmi:id="_gSdukJJVEeesEtnYkurh9A">
+    <packageImport xmi:id="_gSdukJJVEeesEtnYkurh9A">
       <importedPackage xmi:type="uml:Model" href="pathmap://PAPYRUSRE_STANDARDUTILS_MODELLIBARY/PapyrusRE_StandardUtils.modellibrary.uml#_03nSwFOPEeCXkoFpHlFAkw"/>
     </packageImport>
     <packagedElement xmi:type="uml:Profile" xmi:id="_6-xDADp8EeCmwNGSFJpOjg" name="RequirementGenericCharacteristics">
-      <eAnnotations xmi:type="ecore:EAnnotation" xmi:id="_SIcpczp_EeCmwNGSFJpOjg" source="http://www.eclipse.org/uml2/2.0.0/UML">
+      <eAnnotations xmi:id="_SIcpczp_EeCmwNGSFJpOjg" source="http://www.eclipse.org/uml2/2.0.0/UML">
         <contents xmi:type="ecore:EPackage" xmi:id="_u20mMaToEeenne7APpWiQg" name="requirementgenericcharacteristics" nsURI="http://www.eclipse.org/papyrus/requirements/sysml14/0.7.0/PapyrusRE/RequirementGenericCharacteristics" nsPrefix="RequirementGenericCharacteristics">
-          <eAnnotations xmi:type="ecore:EAnnotation" xmi:id="_u20mMqToEeenne7APpWiQg" source="http://www.eclipse.org/uml2/4.1.0/UML">
+          <eAnnotations xmi:id="_u20mMqToEeenne7APpWiQg" source="http://www.eclipse.org/uml2/4.1.0/UML">
             <references xmi:type="ecore:EPackage" href="http://www.eclipse.org/papyrus/sysml/1.4/SysML#//requirements"/>
           </eAnnotations>
-          <eAnnotations xmi:type="ecore:EAnnotation" xmi:id="_u20mM6ToEeenne7APpWiQg" source="http://www.eclipse.org/uml2/2.0.0/UML">
-            <details xmi:type="ecore:EStringToStringMapEntry" xmi:id="_u20mNKToEeenne7APpWiQg" key="originalName" value="RequirementGenericCharacteristics"/>
+          <eAnnotations xmi:id="_u20mM6ToEeenne7APpWiQg" source="http://www.eclipse.org/uml2/2.0.0/UML">
+            <details xmi:id="_u20mNKToEeenne7APpWiQg" key="originalName" value="RequirementGenericCharacteristics"/>
           </eAnnotations>
-          <eAnnotations xmi:type="ecore:EAnnotation" xmi:id="_u25esaToEeenne7APpWiQg" source="PapyrusVersion">
-            <details xmi:type="ecore:EStringToStringMapEntry" xmi:id="_u25esqToEeenne7APpWiQg" key="Version" value="0.0.1"/>
-            <details xmi:type="ecore:EStringToStringMapEntry" xmi:id="_u25es6ToEeenne7APpWiQg" key="Comment" value=""/>
-            <details xmi:type="ecore:EStringToStringMapEntry" xmi:id="_u25etKToEeenne7APpWiQg" key="Copyright" value=""/>
-            <details xmi:type="ecore:EStringToStringMapEntry" xmi:id="_u25etaToEeenne7APpWiQg" key="Date" value="2017-09-29"/>
-            <details xmi:type="ecore:EStringToStringMapEntry" xmi:id="_u25etqToEeenne7APpWiQg" key="Author" value=""/>
+          <eAnnotations xmi:id="_u25esaToEeenne7APpWiQg" source="PapyrusVersion">
+            <details xmi:id="_u25esqToEeenne7APpWiQg" key="Version" value="0.0.1"/>
+            <details xmi:id="_u25es6ToEeenne7APpWiQg" key="Comment" value=""/>
+            <details xmi:id="_u25etKToEeenne7APpWiQg" key="Copyright" value=""/>
+            <details xmi:id="_u25etaToEeenne7APpWiQg" key="Date" value="2017-09-29"/>
+            <details xmi:id="_u25etqToEeenne7APpWiQg" key="Author" value=""/>
           </eAnnotations>
           <eClassifiers xmi:type="ecore:EClass" xmi:id="_u20mNaToEeenne7APpWiQg" name="Requirement">
-            <eAnnotations xmi:type="ecore:EAnnotation" xmi:id="_u20mNqToEeenne7APpWiQg" source="http://www.eclipse.org/uml2/2.0.0/UML" references="_qIm20Dp_EeCmwNGSFJpOjg"/>
-            <eSuperTypes xmi:type="ecore:EClass" href="http://www.eclipse.org/papyrus/sysml/1.4/SysML#//requirements/Requirement"/>
+            <eAnnotations xmi:id="_u20mNqToEeenne7APpWiQg" source="http://www.eclipse.org/uml2/2.0.0/UML" references="_qIm20Dp_EeCmwNGSFJpOjg"/>
+            <eSuperTypes href="http://www.eclipse.org/papyrus/sysml/1.4/SysML#//requirements/Requirement"/>
             <eStructuralFeatures xmi:type="ecore:EAttribute" xmi:id="_u20mN6ToEeenne7APpWiQg" name="agreementStatus" ordered="false">
               <eType xmi:type="ecore:EEnum" href="http://www.eclipse.org/papyrus/requirements/sysml14/0.7.0/PapyrusRE/ModelLibrary/PapyrusREStandardUtils/RequirementAndProcessConcerns#//AgreementStatusKind"/>
             </eStructuralFeatures>
@@ -104,22 +89,22 @@
           </eClassifiers>
         </contents>
         <contents xmi:type="ecore:EPackage" xmi:id="_4wyi8KROEeeur8HW6jKajg" name="requirementgenericcharacteristics" nsURI="http://www.eclipse.org/papyrus/requirement/sysml14/0.7.0/PapyrusRE/RequirementGenericCharacteristics" nsPrefix="RequirementGenericCharacteristics">
-          <eAnnotations xmi:type="ecore:EAnnotation" xmi:id="_4wyi8aROEeeur8HW6jKajg" source="http://www.eclipse.org/uml2/4.1.0/UML">
+          <eAnnotations xmi:id="_4wyi8aROEeeur8HW6jKajg" source="http://www.eclipse.org/uml2/4.1.0/UML">
             <references xmi:type="ecore:EPackage" href="http://www.eclipse.org/papyrus/sysml/1.4/SysML#//requirements"/>
           </eAnnotations>
-          <eAnnotations xmi:type="ecore:EAnnotation" xmi:id="_4wyi8qROEeeur8HW6jKajg" source="http://www.eclipse.org/uml2/2.0.0/UML">
-            <details xmi:type="ecore:EStringToStringMapEntry" xmi:id="_4wyi86ROEeeur8HW6jKajg" key="originalName" value="RequirementGenericCharacteristics"/>
+          <eAnnotations xmi:id="_4wyi8qROEeeur8HW6jKajg" source="http://www.eclipse.org/uml2/2.0.0/UML">
+            <details xmi:id="_4wyi86ROEeeur8HW6jKajg" key="originalName" value="RequirementGenericCharacteristics"/>
           </eAnnotations>
-          <eAnnotations xmi:type="ecore:EAnnotation" xmi:id="_4w4pkaROEeeur8HW6jKajg" source="PapyrusVersion">
-            <details xmi:type="ecore:EStringToStringMapEntry" xmi:id="_4w4pkqROEeeur8HW6jKajg" key="Version" value="0.0.1"/>
-            <details xmi:type="ecore:EStringToStringMapEntry" xmi:id="_4w4pk6ROEeeur8HW6jKajg" key="Comment" value=""/>
-            <details xmi:type="ecore:EStringToStringMapEntry" xmi:id="_4w4plKROEeeur8HW6jKajg" key="Copyright" value=""/>
-            <details xmi:type="ecore:EStringToStringMapEntry" xmi:id="_4w4plaROEeeur8HW6jKajg" key="Date" value="2017-09-28"/>
-            <details xmi:type="ecore:EStringToStringMapEntry" xmi:id="_4w4plqROEeeur8HW6jKajg" key="Author" value=""/>
+          <eAnnotations xmi:id="_4w4pkaROEeeur8HW6jKajg" source="PapyrusVersion">
+            <details xmi:id="_4w4pkqROEeeur8HW6jKajg" key="Version" value="0.0.1"/>
+            <details xmi:id="_4w4pk6ROEeeur8HW6jKajg" key="Comment" value=""/>
+            <details xmi:id="_4w4plKROEeeur8HW6jKajg" key="Copyright" value=""/>
+            <details xmi:id="_4w4plaROEeeur8HW6jKajg" key="Date" value="2017-09-28"/>
+            <details xmi:id="_4w4plqROEeeur8HW6jKajg" key="Author" value=""/>
           </eAnnotations>
           <eClassifiers xmi:type="ecore:EClass" xmi:id="_4wyi9KROEeeur8HW6jKajg" name="Requirement">
-            <eAnnotations xmi:type="ecore:EAnnotation" xmi:id="_4wyi9aROEeeur8HW6jKajg" source="http://www.eclipse.org/uml2/2.0.0/UML" references="_qIm20Dp_EeCmwNGSFJpOjg"/>
-            <eSuperTypes xmi:type="ecore:EClass" href="http://www.eclipse.org/papyrus/sysml/1.4/SysML#//requirements/Requirement"/>
+            <eAnnotations xmi:id="_4wyi9aROEeeur8HW6jKajg" source="http://www.eclipse.org/uml2/2.0.0/UML" references="_qIm20Dp_EeCmwNGSFJpOjg"/>
+            <eSuperTypes href="http://www.eclipse.org/papyrus/sysml/1.4/SysML#//requirements/Requirement"/>
             <eStructuralFeatures xmi:type="ecore:EAttribute" xmi:id="_4wyi9qROEeeur8HW6jKajg" name="agreementStatus" ordered="false">
               <eType xmi:type="ecore:EEnum" href="http://www.eclipse.org/papyrus/requirement/sysml14/0.7.0/PapyrusRE/ModelLibrary/PapyrusREStandardUtils/RequirementAndProcessConcerns#//AgreementStatusKind"/>
             </eStructuralFeatures>
@@ -181,183 +166,183 @@
         </contents>
       </eAnnotations>
       <packagedElement xmi:type="uml:Stereotype" xmi:id="_qIm20Dp_EeCmwNGSFJpOjg" name="Requirement">
-        <generalization xmi:type="uml:Generalization" xmi:id="_O_aoUJInEeeji413eaUmIg">
+        <generalization xmi:id="_O_aoUJInEeeji413eaUmIg">
           <general xmi:type="uml:Stereotype" href="pathmap://SysML14_PROFILES/SysML.profile.uml#SysML.package_packagedElement_Requirements.stereotype_packagedElement_Requirement"/>
         </generalization>
-        <ownedAttribute xmi:type="uml:Property" xmi:id="_AyCZcDqOEeCmwNGSFJpOjg" name="agreementStatus" visibility="public">
+        <ownedAttribute xmi:id="_AyCZcDqOEeCmwNGSFJpOjg" name="agreementStatus" visibility="public">
           <type xmi:type="uml:Enumeration" href="pathmap://PAPYRUSRE_STANDARDUTILS_MODELLIBARY/PapyrusRE_StandardUtils.modellibrary.uml#_ZUhvYFPKEeCXkoFpHlFAkw"/>
           <lowerValue xmi:type="uml:LiteralInteger" xmi:id="_BBrX8DqOEeCmwNGSFJpOjg"/>
           <upperValue xmi:type="uml:LiteralUnlimitedNatural" xmi:id="_BB1I8DqOEeCmwNGSFJpOjg" value="1"/>
         </ownedAttribute>
-        <ownedAttribute xmi:type="uml:Property" xmi:id="_IU1cgDqOEeCmwNGSFJpOjg" name="approvalAuthority" visibility="public">
+        <ownedAttribute xmi:id="_IU1cgDqOEeCmwNGSFJpOjg" name="approvalAuthority" visibility="public">
           <type xmi:type="uml:PrimitiveType" href="pathmap://UML_LIBRARIES/UMLPrimitiveTypes.library.uml#String"/>
           <lowerValue xmi:type="uml:LiteralInteger" xmi:id="_ItRKoDqOEeCmwNGSFJpOjg"/>
           <upperValue xmi:type="uml:LiteralUnlimitedNatural" xmi:id="_Ita7oDqOEeCmwNGSFJpOjg" value="1"/>
         </ownedAttribute>
-        <ownedAttribute xmi:type="uml:Property" xmi:id="_UH4MwDqOEeCmwNGSFJpOjg" name="importance" visibility="public">
+        <ownedAttribute xmi:id="_UH4MwDqOEeCmwNGSFJpOjg" name="importance" visibility="public">
           <type xmi:type="uml:Enumeration" href="pathmap://PAPYRUSRE_STANDARDUTILS_MODELLIBARY/PapyrusRE_StandardUtils.modellibrary.uml#_GAtVIFOlEeCXkoFpHlFAkw"/>
           <lowerValue xmi:type="uml:LiteralInteger" xmi:id="_UcSWgDqOEeCmwNGSFJpOjg"/>
           <upperValue xmi:type="uml:LiteralUnlimitedNatural" xmi:id="_UccHgDqOEeCmwNGSFJpOjg" value="1"/>
         </ownedAttribute>
-        <ownedAttribute xmi:type="uml:Property" xmi:id="_ZUnXYDqOEeCmwNGSFJpOjg" name="lifeCyclePhase" visibility="public">
+        <ownedAttribute xmi:id="_ZUnXYDqOEeCmwNGSFJpOjg" name="lifeCyclePhase" visibility="public">
           <type xmi:type="uml:Enumeration" href="pathmap://PAPYRUSRE_STANDARDUTILS_MODELLIBARY/PapyrusRE_StandardUtils.modellibrary.uml#_HF8JwFOjEeCXkoFpHlFAkw"/>
           <lowerValue xmi:type="uml:LiteralInteger" xmi:id="_ZgZJkDqOEeCmwNGSFJpOjg"/>
           <upperValue xmi:type="uml:LiteralUnlimitedNatural" xmi:id="_ZgsEgDqOEeCmwNGSFJpOjg" value="1"/>
         </ownedAttribute>
-        <ownedAttribute xmi:type="uml:Property" xmi:id="_b3CQ0DqOEeCmwNGSFJpOjg" name="maturity" visibility="public">
+        <ownedAttribute xmi:id="_b3CQ0DqOEeCmwNGSFJpOjg" name="maturity" visibility="public">
           <type xmi:type="uml:PrimitiveType" href="pathmap://UML_LIBRARIES/UMLPrimitiveTypes.library.uml#Integer"/>
           <lowerValue xmi:type="uml:LiteralInteger" xmi:id="_cI6rADqOEeCmwNGSFJpOjg"/>
           <upperValue xmi:type="uml:LiteralUnlimitedNatural" xmi:id="_cJONADqOEeCmwNGSFJpOjg" value="1"/>
         </ownedAttribute>
-        <ownedAttribute xmi:type="uml:Property" xmi:id="_hb61sDqOEeCmwNGSFJpOjg" name="abstractionLevel" visibility="public">
+        <ownedAttribute xmi:id="_hb61sDqOEeCmwNGSFJpOjg" name="abstractionLevel" visibility="public">
           <type xmi:type="uml:Enumeration" href="pathmap://PAPYRUSRE_STANDARDUTILS_MODELLIBARY/PapyrusRE_StandardUtils.modellibrary.uml#_HWoRIFOjEeCXkoFpHlFAkw"/>
           <lowerValue xmi:type="uml:LiteralInteger" xmi:id="_hzUCADqOEeCmwNGSFJpOjg"/>
           <upperValue xmi:type="uml:LiteralUnlimitedNatural" xmi:id="_hzdzADqOEeCmwNGSFJpOjg" value="1"/>
         </ownedAttribute>
-        <ownedAttribute xmi:type="uml:Property" xmi:id="_l1s5YDqOEeCmwNGSFJpOjg" name="owner" visibility="public">
+        <ownedAttribute xmi:id="_l1s5YDqOEeCmwNGSFJpOjg" name="owner" visibility="public">
           <type xmi:type="uml:PrimitiveType" href="pathmap://UML_LIBRARIES/UMLPrimitiveTypes.library.uml#String"/>
           <lowerValue xmi:type="uml:LiteralInteger" xmi:id="_n3ys8DqOEeCmwNGSFJpOjg"/>
           <upperValue xmi:type="uml:LiteralUnlimitedNatural" xmi:id="_n3724DqOEeCmwNGSFJpOjg" value="1"/>
         </ownedAttribute>
-        <ownedAttribute xmi:type="uml:Property" xmi:id="_rPQ_EDqOEeCmwNGSFJpOjg" name="priority" visibility="public">
+        <ownedAttribute xmi:id="_rPQ_EDqOEeCmwNGSFJpOjg" name="priority" visibility="public">
           <type xmi:type="uml:Enumeration" href="pathmap://PAPYRUSRE_STANDARDUTILS_MODELLIBARY/PapyrusRE_StandardUtils.modellibrary.uml#_Fx9ugFOlEeCXkoFpHlFAkw"/>
           <lowerValue xmi:type="uml:LiteralInteger" xmi:id="_rc0S4DqOEeCmwNGSFJpOjg"/>
           <upperValue xmi:type="uml:LiteralUnlimitedNatural" xmi:id="_rc-D4DqOEeCmwNGSFJpOjg" value="1"/>
         </ownedAttribute>
-        <ownedAttribute xmi:type="uml:Property" xmi:id="_ycc-gDqOEeCmwNGSFJpOjg" name="qualificationStatus" visibility="public">
+        <ownedAttribute xmi:id="_ycc-gDqOEeCmwNGSFJpOjg" name="qualificationStatus" visibility="public">
           <type xmi:type="uml:Enumeration" href="pathmap://PAPYRUSRE_STANDARDUTILS_MODELLIBARY/PapyrusRE_StandardUtils.modellibrary.uml#_Zh75QFPKEeCXkoFpHlFAkw"/>
           <lowerValue xmi:type="uml:LiteralInteger" xmi:id="_yrp4IDqOEeCmwNGSFJpOjg"/>
           <upperValue xmi:type="uml:LiteralUnlimitedNatural" xmi:id="_yrzCEDqOEeCmwNGSFJpOjg" value="1"/>
         </ownedAttribute>
-        <ownedAttribute xmi:type="uml:Property" xmi:id="_7EGJwDqOEeCmwNGSFJpOjg" name="reviewStatus" visibility="public">
+        <ownedAttribute xmi:id="_7EGJwDqOEeCmwNGSFJpOjg" name="reviewStatus" visibility="public">
           <type xmi:type="uml:Enumeration" href="pathmap://PAPYRUSRE_STANDARDUTILS_MODELLIBARY/PapyrusRE_StandardUtils.modellibrary.uml#_ZuThUFPKEeCXkoFpHlFAkw"/>
           <lowerValue xmi:type="uml:LiteralInteger" xmi:id="_8LLGkDqOEeCmwNGSFJpOjg"/>
           <upperValue xmi:type="uml:LiteralUnlimitedNatural" xmi:id="_8LUQgDqOEeCmwNGSFJpOjg" value="1"/>
         </ownedAttribute>
-        <ownedAttribute xmi:type="uml:Property" xmi:id="_95vhMDqOEeCmwNGSFJpOjg" name="satisfactionRationale" visibility="public">
+        <ownedAttribute xmi:id="_95vhMDqOEeCmwNGSFJpOjg" name="satisfactionRationale" visibility="public">
           <type xmi:type="uml:PrimitiveType" href="pathmap://UML_LIBRARIES/UMLPrimitiveTypes.library.uml#String"/>
           <lowerValue xmi:type="uml:LiteralInteger" xmi:id="_-QPVoDqOEeCmwNGSFJpOjg"/>
           <upperValue xmi:type="uml:LiteralUnlimitedNatural" xmi:id="_-QZGoDqOEeCmwNGSFJpOjg" value="1"/>
         </ownedAttribute>
-        <ownedAttribute xmi:type="uml:Property" xmi:id="_C2iLUDqPEeCmwNGSFJpOjg" name="satisfactionStatus" visibility="public">
+        <ownedAttribute xmi:id="_C2iLUDqPEeCmwNGSFJpOjg" name="satisfactionStatus" visibility="public">
           <type xmi:type="uml:Enumeration" href="pathmap://PAPYRUSRE_STANDARDUTILS_MODELLIBARY/PapyrusRE_StandardUtils.modellibrary.uml#_ZnvmUFPKEeCXkoFpHlFAkw"/>
           <lowerValue xmi:type="uml:LiteralInteger" xmi:id="_DEGGMDqPEeCmwNGSFJpOjg"/>
           <upperValue xmi:type="uml:LiteralUnlimitedNatural" xmi:id="_DEP3MDqPEeCmwNGSFJpOjg" value="1"/>
         </ownedAttribute>
-        <ownedAttribute xmi:type="uml:Property" xmi:id="_H2A9EDqPEeCmwNGSFJpOjg" name="source" visibility="public">
+        <ownedAttribute xmi:id="_H2A9EDqPEeCmwNGSFJpOjg" name="source" visibility="public">
           <type xmi:type="uml:PrimitiveType" href="pathmap://UML_LIBRARIES/UMLPrimitiveTypes.library.uml#String"/>
           <lowerValue xmi:type="uml:LiteralInteger" xmi:id="_ICPbMDqPEeCmwNGSFJpOjg"/>
           <upperValue xmi:type="uml:LiteralUnlimitedNatural" xmi:id="_ICYlIDqPEeCmwNGSFJpOjg" value="1"/>
         </ownedAttribute>
-        <ownedAttribute xmi:type="uml:Property" xmi:id="_JzfWYDqPEeCmwNGSFJpOjg" name="validationRationale" visibility="public">
+        <ownedAttribute xmi:id="_JzfWYDqPEeCmwNGSFJpOjg" name="validationRationale" visibility="public">
           <type xmi:type="uml:PrimitiveType" href="pathmap://UML_LIBRARIES/UMLPrimitiveTypes.library.uml#String"/>
           <lowerValue xmi:type="uml:LiteralInteger" xmi:id="_LukjADqPEeCmwNGSFJpOjg"/>
           <upperValue xmi:type="uml:LiteralUnlimitedNatural" xmi:id="_Luts8DqPEeCmwNGSFJpOjg" value="1"/>
         </ownedAttribute>
-        <ownedAttribute xmi:type="uml:Property" xmi:id="_PqGkcDqPEeCmwNGSFJpOjg" name="validatorName" visibility="public">
+        <ownedAttribute xmi:id="_PqGkcDqPEeCmwNGSFJpOjg" name="validatorName" visibility="public">
           <type xmi:type="uml:PrimitiveType" href="pathmap://UML_LIBRARIES/UMLPrimitiveTypes.library.uml#String"/>
           <lowerValue xmi:type="uml:LiteralInteger" xmi:id="_PzyE4DqPEeCmwNGSFJpOjg"/>
           <upperValue xmi:type="uml:LiteralUnlimitedNatural" xmi:id="_Pz714DqPEeCmwNGSFJpOjg" value="1"/>
         </ownedAttribute>
-        <ownedAttribute xmi:type="uml:Property" xmi:id="_TpNeUDqPEeCmwNGSFJpOjg" name="verifierName" visibility="public">
+        <ownedAttribute xmi:id="_TpNeUDqPEeCmwNGSFJpOjg" name="verifierName" visibility="public">
           <type xmi:type="uml:PrimitiveType" href="pathmap://UML_LIBRARIES/UMLPrimitiveTypes.library.uml#String"/>
           <lowerValue xmi:type="uml:LiteralInteger" xmi:id="_T0PCkDqPEeCmwNGSFJpOjg"/>
           <upperValue xmi:type="uml:LiteralUnlimitedNatural" xmi:id="_T0YzkDqPEeCmwNGSFJpOjg" value="1"/>
         </ownedAttribute>
-        <ownedAttribute xmi:type="uml:Property" xmi:id="_VW4hEDqPEeCmwNGSFJpOjg" name="VV_Method" visibility="public">
+        <ownedAttribute xmi:id="_VW4hEDqPEeCmwNGSFJpOjg" name="VV_Method" visibility="public">
           <type xmi:type="uml:Enumeration" href="pathmap://PAPYRUSRE_STANDARDUTILS_MODELLIBARY/PapyrusRE_StandardUtils.modellibrary.uml#__xkAkFPLEeCXkoFpHlFAkw"/>
           <lowerValue xmi:type="uml:LiteralInteger" xmi:id="_WTO0kDqPEeCmwNGSFJpOjg"/>
           <upperValue xmi:type="uml:LiteralUnlimitedNatural" xmi:id="_WTYlkDqPEeCmwNGSFJpOjg" value="1"/>
         </ownedAttribute>
-        <ownedAttribute xmi:type="uml:Property" xmi:id="_XyckkDqPEeCmwNGSFJpOjg" name="VV_Status" visibility="public">
+        <ownedAttribute xmi:id="_XyckkDqPEeCmwNGSFJpOjg" name="VV_Status" visibility="public">
           <type xmi:type="uml:Enumeration" href="pathmap://PAPYRUSRE_STANDARDUTILS_MODELLIBARY/PapyrusRE_StandardUtils.modellibrary.uml#_AF-KUFPMEeCXkoFpHlFAkw"/>
           <lowerValue xmi:type="uml:LiteralInteger" xmi:id="_X71xIDqPEeCmwNGSFJpOjg"/>
           <upperValue xmi:type="uml:LiteralUnlimitedNatural" xmi:id="_X7-7EDqPEeCmwNGSFJpOjg" value="1"/>
         </ownedAttribute>
-        <ownedAttribute xmi:type="uml:Property" xmi:id="_JCYBUJJXEeesEtnYkurh9A" name="qualityNature" visibility="public">
+        <ownedAttribute xmi:id="_JCYBUJJXEeesEtnYkurh9A" name="qualityNature" visibility="public">
           <type xmi:type="uml:Enumeration" href="pathmap://PAPYRUSRE_STANDARDUTILS_MODELLIBARY/PapyrusRE_StandardUtils.modellibrary.uml#_aChacFOhEeCXkoFpHlFAkw"/>
           <lowerValue xmi:type="uml:LiteralInteger" xmi:id="_JCYBUZJXEeesEtnYkurh9A"/>
           <upperValue xmi:type="uml:LiteralUnlimitedNatural" xmi:id="_JCYBUpJXEeesEtnYkurh9A" value="1"/>
         </ownedAttribute>
       </packagedElement>
-      <profileApplication xmi:type="uml:ProfileApplication" xmi:id="_ofvaoKK_EeeYBKEUTtrY-A">
-        <eAnnotations xmi:type="ecore:EAnnotation" xmi:id="_ofx24KK_EeeYBKEUTtrY-A" source="http://www.eclipse.org/uml2/2.0.0/UML">
+      <profileApplication xmi:id="_ofvaoKK_EeeYBKEUTtrY-A">
+        <eAnnotations xmi:id="_ofx24KK_EeeYBKEUTtrY-A" source="http://www.eclipse.org/uml2/2.0.0/UML">
           <references xmi:type="ecore:EPackage" href="pathmap://UML_PROFILES/Ecore.profile.uml#_z1OFcHjqEdy8S4Cr8Rc_NA"/>
         </eAnnotations>
-        <appliedProfile xmi:type="uml:Profile" href="pathmap://UML_PROFILES/Ecore.profile.uml#_0"/>
+        <appliedProfile href="pathmap://UML_PROFILES/Ecore.profile.uml#_0"/>
       </profileApplication>
     </packagedElement>
     <packagedElement xmi:type="uml:Profile" xmi:id="_7P52UDp8EeCmwNGSFJpOjg" name="RequirementClassification">
-      <eAnnotations xmi:type="ecore:EAnnotation" xmi:id="_SIcpdjp_EeCmwNGSFJpOjg" source="http://www.eclipse.org/uml2/2.0.0/UML">
+      <eAnnotations xmi:id="_SIcpdjp_EeCmwNGSFJpOjg" source="http://www.eclipse.org/uml2/2.0.0/UML">
         <contents xmi:type="ecore:EPackage" xmi:id="_u22bYaToEeenne7APpWiQg" name="requirementclassification" nsURI="http://www.eclipse.org/papyrus/requirements/sysml14/0.7.0/PapyrusRE/RequirementClassification" nsPrefix="RequirementClassification">
-          <eAnnotations xmi:type="ecore:EAnnotation" xmi:id="_u22bYqToEeenne7APpWiQg" source="http://www.eclipse.org/uml2/4.1.0/UML" references="_u20mMaToEeenne7APpWiQg"/>
-          <eAnnotations xmi:type="ecore:EAnnotation" xmi:id="_u22bY6ToEeenne7APpWiQg" source="http://www.eclipse.org/uml2/2.0.0/UML">
-            <details xmi:type="ecore:EStringToStringMapEntry" xmi:id="_u22bZKToEeenne7APpWiQg" key="originalName" value="RequirementClassification"/>
+          <eAnnotations xmi:id="_u22bYqToEeenne7APpWiQg" source="http://www.eclipse.org/uml2/4.1.0/UML" references="_u20mMaToEeenne7APpWiQg"/>
+          <eAnnotations xmi:id="_u22bY6ToEeenne7APpWiQg" source="http://www.eclipse.org/uml2/2.0.0/UML">
+            <details xmi:id="_u22bZKToEeenne7APpWiQg" key="originalName" value="RequirementClassification"/>
           </eAnnotations>
-          <eAnnotations xmi:type="ecore:EAnnotation" xmi:id="_u25et6ToEeenne7APpWiQg" source="PapyrusVersion">
-            <details xmi:type="ecore:EStringToStringMapEntry" xmi:id="_u25euKToEeenne7APpWiQg" key="Version" value="0.0.1"/>
-            <details xmi:type="ecore:EStringToStringMapEntry" xmi:id="_u25euaToEeenne7APpWiQg" key="Comment" value=""/>
-            <details xmi:type="ecore:EStringToStringMapEntry" xmi:id="_u25euqToEeenne7APpWiQg" key="Copyright" value=""/>
-            <details xmi:type="ecore:EStringToStringMapEntry" xmi:id="_u25eu6ToEeenne7APpWiQg" key="Date" value="2017-09-29"/>
-            <details xmi:type="ecore:EStringToStringMapEntry" xmi:id="_u25evKToEeenne7APpWiQg" key="Author" value=""/>
+          <eAnnotations xmi:id="_u25et6ToEeenne7APpWiQg" source="PapyrusVersion">
+            <details xmi:id="_u25euKToEeenne7APpWiQg" key="Version" value="0.0.1"/>
+            <details xmi:id="_u25euaToEeenne7APpWiQg" key="Comment" value=""/>
+            <details xmi:id="_u25euqToEeenne7APpWiQg" key="Copyright" value=""/>
+            <details xmi:id="_u25eu6ToEeenne7APpWiQg" key="Date" value="2017-09-29"/>
+            <details xmi:id="_u25evKToEeenne7APpWiQg" key="Author" value=""/>
           </eAnnotations>
           <eClassifiers xmi:type="ecore:EClass" xmi:id="_u22bZaToEeenne7APpWiQg" name="ProjectRequirement" eSuperTypes="_u20mNaToEeenne7APpWiQg">
-            <eAnnotations xmi:type="ecore:EAnnotation" xmi:id="_u22bZqToEeenne7APpWiQg" source="http://www.eclipse.org/uml2/2.0.0/UML" references="_BuF6YDqAEeCmwNGSFJpOjg"/>
+            <eAnnotations xmi:id="_u22bZqToEeenne7APpWiQg" source="http://www.eclipse.org/uml2/2.0.0/UML" references="_BuF6YDqAEeCmwNGSFJpOjg"/>
           </eClassifiers>
           <eClassifiers xmi:type="ecore:EClass" xmi:id="_u22baKToEeenne7APpWiQg" name="ProcessRequirement" eSuperTypes="_u20mNaToEeenne7APpWiQg">
-            <eAnnotations xmi:type="ecore:EAnnotation" xmi:id="_u22baaToEeenne7APpWiQg" source="http://www.eclipse.org/uml2/2.0.0/UML" references="_DNURcDqAEeCmwNGSFJpOjg"/>
+            <eAnnotations xmi:id="_u22baaToEeenne7APpWiQg" source="http://www.eclipse.org/uml2/2.0.0/UML" references="_DNURcDqAEeCmwNGSFJpOjg"/>
           </eClassifiers>
           <eClassifiers xmi:type="ecore:EClass" xmi:id="_u22ba6ToEeenne7APpWiQg" name="ConstraintRequirement" eSuperTypes="_u20mNaToEeenne7APpWiQg">
-            <eAnnotations xmi:type="ecore:EAnnotation" xmi:id="_u22bbKToEeenne7APpWiQg" source="http://www.eclipse.org/uml2/2.0.0/UML" references="_IBDQwDqBEeCmwNGSFJpOjg"/>
+            <eAnnotations xmi:id="_u22bbKToEeenne7APpWiQg" source="http://www.eclipse.org/uml2/2.0.0/UML" references="_IBDQwDqBEeCmwNGSFJpOjg"/>
             <eStructuralFeatures xmi:type="ecore:EAttribute" xmi:id="_u22bbaToEeenne7APpWiQg" name="constraintKind" ordered="false" lowerBound="1">
               <eType xmi:type="ecore:EEnum" href="http://www.eclipse.org/papyrus/requirements/sysml14/0.7.0/PapyrusRE/ModelLibrary/PapyrusREStandardUtils/RequirementClassificationConcerns#//ConstraintKind"/>
             </eStructuralFeatures>
           </eClassifiers>
           <eClassifiers xmi:type="ecore:EClass" xmi:id="_u22bcKToEeenne7APpWiQg" name="WorkloadCapacityRequirement" eSuperTypes="_u20mNaToEeenne7APpWiQg">
-            <eAnnotations xmi:type="ecore:EAnnotation" xmi:id="_u22bcaToEeenne7APpWiQg" source="http://www.eclipse.org/uml2/2.0.0/UML" references="_QhT9cDqIEeCmwNGSFJpOjg"/>
+            <eAnnotations xmi:id="_u22bcaToEeenne7APpWiQg" source="http://www.eclipse.org/uml2/2.0.0/UML" references="_QhT9cDqIEeCmwNGSFJpOjg"/>
             <eStructuralFeatures xmi:type="ecore:EAttribute" xmi:id="_u22bcqToEeenne7APpWiQg" name="workloadCapacity" ordered="false" lowerBound="1">
               <eType xmi:type="ecore:EEnum" href="http://www.eclipse.org/papyrus/requirements/sysml14/0.7.0/PapyrusRE/ModelLibrary/PapyrusREStandardUtils/RequirementClassificationConcerns#//WorkloadCapacitiesKind"/>
             </eStructuralFeatures>
           </eClassifiers>
           <eClassifiers xmi:type="ecore:EClass" xmi:id="_u22bdaToEeenne7APpWiQg" name="QualityRequirement" eSuperTypes="_u20mNaToEeenne7APpWiQg">
-            <eAnnotations xmi:type="ecore:EAnnotation" xmi:id="_u22bdqToEeenne7APpWiQg" source="http://www.eclipse.org/uml2/2.0.0/UML" references="_Q2eVIDqIEeCmwNGSFJpOjg"/>
+            <eAnnotations xmi:id="_u22bdqToEeenne7APpWiQg" source="http://www.eclipse.org/uml2/2.0.0/UML" references="_Q2eVIDqIEeCmwNGSFJpOjg"/>
             <eStructuralFeatures xmi:type="ecore:EAttribute" xmi:id="_u22bd6ToEeenne7APpWiQg" name="specificQualityKind" ordered="false" lowerBound="1">
               <eType xmi:type="ecore:EEnum" href="http://www.eclipse.org/papyrus/requirements/sysml14/0.7.0/PapyrusRE/ModelLibrary/PapyrusREStandardUtils/RequirementClassificationConcerns#//QualityKind"/>
             </eStructuralFeatures>
           </eClassifiers>
         </contents>
         <contents xmi:type="ecore:EPackage" xmi:id="_4wzxEaROEeeur8HW6jKajg" name="requirementclassification" nsURI="http://www.eclipse.org/papyrus/requirement/sysml14/0.7.0/PapyrusRE/RequirementClassification" nsPrefix="RequirementClassification">
-          <eAnnotations xmi:type="ecore:EAnnotation" xmi:id="_4wzxEqROEeeur8HW6jKajg" source="http://www.eclipse.org/uml2/4.1.0/UML" references="_4wyi8KROEeeur8HW6jKajg"/>
-          <eAnnotations xmi:type="ecore:EAnnotation" xmi:id="_4wzxE6ROEeeur8HW6jKajg" source="http://www.eclipse.org/uml2/2.0.0/UML">
-            <details xmi:type="ecore:EStringToStringMapEntry" xmi:id="_4wzxFKROEeeur8HW6jKajg" key="originalName" value="RequirementClassification"/>
+          <eAnnotations xmi:id="_4wzxEqROEeeur8HW6jKajg" source="http://www.eclipse.org/uml2/4.1.0/UML" references="_4wyi8KROEeeur8HW6jKajg"/>
+          <eAnnotations xmi:id="_4wzxE6ROEeeur8HW6jKajg" source="http://www.eclipse.org/uml2/2.0.0/UML">
+            <details xmi:id="_4wzxFKROEeeur8HW6jKajg" key="originalName" value="RequirementClassification"/>
           </eAnnotations>
-          <eAnnotations xmi:type="ecore:EAnnotation" xmi:id="_4w5QoKROEeeur8HW6jKajg" source="PapyrusVersion">
-            <details xmi:type="ecore:EStringToStringMapEntry" xmi:id="_4w5QoaROEeeur8HW6jKajg" key="Version" value="0.0.1"/>
-            <details xmi:type="ecore:EStringToStringMapEntry" xmi:id="_4w5QoqROEeeur8HW6jKajg" key="Comment" value=""/>
-            <details xmi:type="ecore:EStringToStringMapEntry" xmi:id="_4w5Qo6ROEeeur8HW6jKajg" key="Copyright" value=""/>
-            <details xmi:type="ecore:EStringToStringMapEntry" xmi:id="_4w5QpKROEeeur8HW6jKajg" key="Date" value="2017-09-28"/>
-            <details xmi:type="ecore:EStringToStringMapEntry" xmi:id="_4w5QpaROEeeur8HW6jKajg" key="Author" value=""/>
+          <eAnnotations xmi:id="_4w5QoKROEeeur8HW6jKajg" source="PapyrusVersion">
+            <details xmi:id="_4w5QoaROEeeur8HW6jKajg" key="Version" value="0.0.1"/>
+            <details xmi:id="_4w5QoqROEeeur8HW6jKajg" key="Comment" value=""/>
+            <details xmi:id="_4w5Qo6ROEeeur8HW6jKajg" key="Copyright" value=""/>
+            <details xmi:id="_4w5QpKROEeeur8HW6jKajg" key="Date" value="2017-09-28"/>
+            <details xmi:id="_4w5QpaROEeeur8HW6jKajg" key="Author" value=""/>
           </eAnnotations>
           <eClassifiers xmi:type="ecore:EClass" xmi:id="_4wzxFaROEeeur8HW6jKajg" name="ProjectRequirement" eSuperTypes="_4wyi9KROEeeur8HW6jKajg">
-            <eAnnotations xmi:type="ecore:EAnnotation" xmi:id="_4wzxFqROEeeur8HW6jKajg" source="http://www.eclipse.org/uml2/2.0.0/UML" references="_BuF6YDqAEeCmwNGSFJpOjg"/>
+            <eAnnotations xmi:id="_4wzxFqROEeeur8HW6jKajg" source="http://www.eclipse.org/uml2/2.0.0/UML" references="_BuF6YDqAEeCmwNGSFJpOjg"/>
           </eClassifiers>
           <eClassifiers xmi:type="ecore:EClass" xmi:id="_4wzxGKROEeeur8HW6jKajg" name="ProcessRequirement" eSuperTypes="_4wyi9KROEeeur8HW6jKajg">
-            <eAnnotations xmi:type="ecore:EAnnotation" xmi:id="_4wzxGaROEeeur8HW6jKajg" source="http://www.eclipse.org/uml2/2.0.0/UML" references="_DNURcDqAEeCmwNGSFJpOjg"/>
+            <eAnnotations xmi:id="_4wzxGaROEeeur8HW6jKajg" source="http://www.eclipse.org/uml2/2.0.0/UML" references="_DNURcDqAEeCmwNGSFJpOjg"/>
           </eClassifiers>
           <eClassifiers xmi:type="ecore:EClass" xmi:id="_4wzxG6ROEeeur8HW6jKajg" name="ConstraintRequirement" eSuperTypes="_4wyi9KROEeeur8HW6jKajg">
-            <eAnnotations xmi:type="ecore:EAnnotation" xmi:id="_4wzxHKROEeeur8HW6jKajg" source="http://www.eclipse.org/uml2/2.0.0/UML" references="_IBDQwDqBEeCmwNGSFJpOjg"/>
+            <eAnnotations xmi:id="_4wzxHKROEeeur8HW6jKajg" source="http://www.eclipse.org/uml2/2.0.0/UML" references="_IBDQwDqBEeCmwNGSFJpOjg"/>
             <eStructuralFeatures xmi:type="ecore:EAttribute" xmi:id="_4wzxHaROEeeur8HW6jKajg" name="constraintKind" ordered="false" lowerBound="1">
               <eType xmi:type="ecore:EEnum" href="http://www.eclipse.org/papyrus/requirement/sysml14/0.7.0/PapyrusRE/ModelLibrary/PapyrusREStandardUtils/RequirementClassificationConcerns#//ConstraintKind"/>
             </eStructuralFeatures>
           </eClassifiers>
           <eClassifiers xmi:type="ecore:EClass" xmi:id="_4wzxIKROEeeur8HW6jKajg" name="WorkloadCapacityRequirement" eSuperTypes="_4wyi9KROEeeur8HW6jKajg">
-            <eAnnotations xmi:type="ecore:EAnnotation" xmi:id="_4wzxIaROEeeur8HW6jKajg" source="http://www.eclipse.org/uml2/2.0.0/UML" references="_QhT9cDqIEeCmwNGSFJpOjg"/>
+            <eAnnotations xmi:id="_4wzxIaROEeeur8HW6jKajg" source="http://www.eclipse.org/uml2/2.0.0/UML" references="_QhT9cDqIEeCmwNGSFJpOjg"/>
             <eStructuralFeatures xmi:type="ecore:EAttribute" xmi:id="_4wzxIqROEeeur8HW6jKajg" name="workloadCapacity" ordered="false" lowerBound="1">
               <eType xmi:type="ecore:EEnum" href="http://www.eclipse.org/papyrus/requirement/sysml14/0.7.0/PapyrusRE/ModelLibrary/PapyrusREStandardUtils/RequirementClassificationConcerns#//WorkloadCapacitiesKind"/>
             </eStructuralFeatures>
           </eClassifiers>
           <eClassifiers xmi:type="ecore:EClass" xmi:id="_4wzxJaROEeeur8HW6jKajg" name="QualityRequirement" eSuperTypes="_4wyi9KROEeeur8HW6jKajg">
-            <eAnnotations xmi:type="ecore:EAnnotation" xmi:id="_4wzxJqROEeeur8HW6jKajg" source="http://www.eclipse.org/uml2/2.0.0/UML" references="_Q2eVIDqIEeCmwNGSFJpOjg"/>
+            <eAnnotations xmi:id="_4wzxJqROEeeur8HW6jKajg" source="http://www.eclipse.org/uml2/2.0.0/UML" references="_Q2eVIDqIEeCmwNGSFJpOjg"/>
             <eStructuralFeatures xmi:type="ecore:EAttribute" xmi:id="_4wzxJ6ROEeeur8HW6jKajg" name="specificQualityKind" ordered="false" lowerBound="1">
               <eType xmi:type="ecore:EEnum" href="http://www.eclipse.org/papyrus/requirement/sysml14/0.7.0/PapyrusRE/ModelLibrary/PapyrusREStandardUtils/RequirementClassificationConcerns#//QualityKind"/>
             </eStructuralFeatures>
@@ -365,61 +350,61 @@
         </contents>
       </eAnnotations>
       <packagedElement xmi:type="uml:Stereotype" xmi:id="_BuF6YDqAEeCmwNGSFJpOjg" name="ProjectRequirement">
-        <generalization xmi:type="uml:Generalization" xmi:id="_dW3NMDqAEeCmwNGSFJpOjg" general="_qIm20Dp_EeCmwNGSFJpOjg"/>
+        <generalization xmi:id="_dW3NMDqAEeCmwNGSFJpOjg" general="_qIm20Dp_EeCmwNGSFJpOjg"/>
       </packagedElement>
       <packagedElement xmi:type="uml:Stereotype" xmi:id="_DNURcDqAEeCmwNGSFJpOjg" name="ProcessRequirement">
-        <generalization xmi:type="uml:Generalization" xmi:id="_b4ZEEDqAEeCmwNGSFJpOjg" general="_qIm20Dp_EeCmwNGSFJpOjg"/>
+        <generalization xmi:id="_b4ZEEDqAEeCmwNGSFJpOjg" general="_qIm20Dp_EeCmwNGSFJpOjg"/>
       </packagedElement>
       <packagedElement xmi:type="uml:Stereotype" xmi:id="_IBDQwDqBEeCmwNGSFJpOjg" name="ConstraintRequirement">
-        <generalization xmi:type="uml:Generalization" xmi:id="_sAAOkDqFEeCmwNGSFJpOjg" general="_qIm20Dp_EeCmwNGSFJpOjg"/>
-        <ownedAttribute xmi:type="uml:Property" xmi:id="_JJCaQDqGEeCmwNGSFJpOjg" name="constraintKind" visibility="public">
+        <generalization xmi:id="_sAAOkDqFEeCmwNGSFJpOjg" general="_qIm20Dp_EeCmwNGSFJpOjg"/>
+        <ownedAttribute xmi:id="_JJCaQDqGEeCmwNGSFJpOjg" name="constraintKind" visibility="public">
           <type xmi:type="uml:Enumeration" href="pathmap://PAPYRUSRE_STANDARDUTILS_MODELLIBARY/PapyrusRE_StandardUtils.modellibrary.uml#_azPFsFOhEeCXkoFpHlFAkw"/>
           <lowerValue xmi:type="uml:LiteralInteger" xmi:id="_JVaCUDqGEeCmwNGSFJpOjg" value="1"/>
           <upperValue xmi:type="uml:LiteralUnlimitedNatural" xmi:id="_JVs9QDqGEeCmwNGSFJpOjg" value="1"/>
         </ownedAttribute>
       </packagedElement>
       <packagedElement xmi:type="uml:Stereotype" xmi:id="_QhT9cDqIEeCmwNGSFJpOjg" name="WorkloadCapacityRequirement">
-        <generalization xmi:type="uml:Generalization" xmi:id="_ROrH0DqKEeCmwNGSFJpOjg" general="_qIm20Dp_EeCmwNGSFJpOjg"/>
-        <ownedAttribute xmi:type="uml:Property" xmi:id="_-PTwQDqIEeCmwNGSFJpOjg" name="workloadCapacity" visibility="public">
+        <generalization xmi:id="_ROrH0DqKEeCmwNGSFJpOjg" general="_qIm20Dp_EeCmwNGSFJpOjg"/>
+        <ownedAttribute xmi:id="_-PTwQDqIEeCmwNGSFJpOjg" name="workloadCapacity" visibility="public">
           <type xmi:type="uml:Enumeration" href="pathmap://PAPYRUSRE_STANDARDUTILS_MODELLIBARY/PapyrusRE_StandardUtils.modellibrary.uml#_bDBOIFOhEeCXkoFpHlFAkw"/>
           <lowerValue xmi:type="uml:LiteralInteger" xmi:id="_-YPp0DqIEeCmwNGSFJpOjg" value="1"/>
           <upperValue xmi:type="uml:LiteralUnlimitedNatural" xmi:id="_-YZa0DqIEeCmwNGSFJpOjg" value="1"/>
         </ownedAttribute>
       </packagedElement>
       <packagedElement xmi:type="uml:Stereotype" xmi:id="_Q2eVIDqIEeCmwNGSFJpOjg" name="QualityRequirement">
-        <generalization xmi:type="uml:Generalization" xmi:id="_R5JBIDqKEeCmwNGSFJpOjg" general="_qIm20Dp_EeCmwNGSFJpOjg"/>
-        <ownedAttribute xmi:type="uml:Property" xmi:id="_9r120DqIEeCmwNGSFJpOjg" name="specificQualityKind" visibility="public">
+        <generalization xmi:id="_R5JBIDqKEeCmwNGSFJpOjg" general="_qIm20Dp_EeCmwNGSFJpOjg"/>
+        <ownedAttribute xmi:id="_9r120DqIEeCmwNGSFJpOjg" name="specificQualityKind" visibility="public">
           <type xmi:type="uml:Enumeration" href="pathmap://PAPYRUSRE_STANDARDUTILS_MODELLIBARY/PapyrusRE_StandardUtils.modellibrary.uml#_aChacFOhEeCXkoFpHlFAkw"/>
           <lowerValue xmi:type="uml:LiteralInteger" xmi:id="_9105QDqIEeCmwNGSFJpOjg" value="1"/>
           <upperValue xmi:type="uml:LiteralUnlimitedNatural" xmi:id="_91-qQDqIEeCmwNGSFJpOjg" value="1"/>
         </ownedAttribute>
       </packagedElement>
-      <profileApplication xmi:type="uml:ProfileApplication" xmi:id="_5X-jEKK_EeeYBKEUTtrY-A">
-        <eAnnotations xmi:type="ecore:EAnnotation" xmi:id="_5X_KIKK_EeeYBKEUTtrY-A" source="http://www.eclipse.org/uml2/2.0.0/UML">
+      <profileApplication xmi:id="_5X-jEKK_EeeYBKEUTtrY-A">
+        <eAnnotations xmi:id="_5X_KIKK_EeeYBKEUTtrY-A" source="http://www.eclipse.org/uml2/2.0.0/UML">
           <references xmi:type="ecore:EPackage" href="pathmap://UML_PROFILES/Ecore.profile.uml#_z1OFcHjqEdy8S4Cr8Rc_NA"/>
         </eAnnotations>
-        <appliedProfile xmi:type="uml:Profile" href="pathmap://UML_PROFILES/Ecore.profile.uml#_0"/>
+        <appliedProfile href="pathmap://UML_PROFILES/Ecore.profile.uml#_0"/>
       </profileApplication>
     </packagedElement>
     <packagedElement xmi:type="uml:Profile" xmi:id="_7uTCgDp8EeCmwNGSFJpOjg" name="RequirementTraceability">
-      <eAnnotations xmi:type="ecore:EAnnotation" xmi:id="_SIcpeTp_EeCmwNGSFJpOjg" source="http://www.eclipse.org/uml2/2.0.0/UML">
+      <eAnnotations xmi:id="_SIcpeTp_EeCmwNGSFJpOjg" source="http://www.eclipse.org/uml2/2.0.0/UML">
         <contents xmi:type="ecore:EPackage" xmi:id="_u23CcaToEeenne7APpWiQg" name="requirementtraceability" nsURI="http://www.eclipse.org/papyrus/requirements/sysml14/0.7.0/PapyrusRE/RequirementTraceability" nsPrefix="RequirementTraceability">
-          <eAnnotations xmi:type="ecore:EAnnotation" xmi:id="_u23CcqToEeenne7APpWiQg" source="http://www.eclipse.org/uml2/4.1.0/UML">
+          <eAnnotations xmi:id="_u23CcqToEeenne7APpWiQg" source="http://www.eclipse.org/uml2/4.1.0/UML">
             <references xmi:type="ecore:EPackage" href="http://www.eclipse.org/papyrus/sysml/1.4/SysML#//requirements"/>
           </eAnnotations>
-          <eAnnotations xmi:type="ecore:EAnnotation" xmi:id="_u23Cc6ToEeenne7APpWiQg" source="http://www.eclipse.org/uml2/2.0.0/UML">
-            <details xmi:type="ecore:EStringToStringMapEntry" xmi:id="_u23CdKToEeenne7APpWiQg" key="originalName" value="RequirementTraceability"/>
+          <eAnnotations xmi:id="_u23Cc6ToEeenne7APpWiQg" source="http://www.eclipse.org/uml2/2.0.0/UML">
+            <details xmi:id="_u23CdKToEeenne7APpWiQg" key="originalName" value="RequirementTraceability"/>
           </eAnnotations>
-          <eAnnotations xmi:type="ecore:EAnnotation" xmi:id="_u26FwqToEeenne7APpWiQg" source="PapyrusVersion">
-            <details xmi:type="ecore:EStringToStringMapEntry" xmi:id="_u26Fw6ToEeenne7APpWiQg" key="Version" value="0.0.1"/>
-            <details xmi:type="ecore:EStringToStringMapEntry" xmi:id="_u26FxKToEeenne7APpWiQg" key="Comment" value=""/>
-            <details xmi:type="ecore:EStringToStringMapEntry" xmi:id="_u26FxaToEeenne7APpWiQg" key="Copyright" value=""/>
-            <details xmi:type="ecore:EStringToStringMapEntry" xmi:id="_u26FxqToEeenne7APpWiQg" key="Date" value="2017-09-29"/>
-            <details xmi:type="ecore:EStringToStringMapEntry" xmi:id="_u26Fx6ToEeenne7APpWiQg" key="Author" value=""/>
+          <eAnnotations xmi:id="_u26FwqToEeenne7APpWiQg" source="PapyrusVersion">
+            <details xmi:id="_u26Fw6ToEeenne7APpWiQg" key="Version" value="0.0.1"/>
+            <details xmi:id="_u26FxKToEeenne7APpWiQg" key="Comment" value=""/>
+            <details xmi:id="_u26FxaToEeenne7APpWiQg" key="Copyright" value=""/>
+            <details xmi:id="_u26FxqToEeenne7APpWiQg" key="Date" value="2017-09-29"/>
+            <details xmi:id="_u26Fx6ToEeenne7APpWiQg" key="Author" value=""/>
           </eAnnotations>
           <eClassifiers xmi:type="ecore:EClass" xmi:id="_u23CdaToEeenne7APpWiQg" name="Satisfy">
-            <eAnnotations xmi:type="ecore:EAnnotation" xmi:id="_u23CdqToEeenne7APpWiQg" source="http://www.eclipse.org/uml2/2.0.0/UML" references="_7X8dYDqPEeCmwNGSFJpOjg"/>
-            <eSuperTypes xmi:type="ecore:EClass" href="http://www.eclipse.org/papyrus/sysml/1.4/SysML#//requirements/Satisfy"/>
+            <eAnnotations xmi:id="_u23CdqToEeenne7APpWiQg" source="http://www.eclipse.org/uml2/2.0.0/UML" references="_7X8dYDqPEeCmwNGSFJpOjg"/>
+            <eSuperTypes href="http://www.eclipse.org/papyrus/sysml/1.4/SysML#//requirements/Satisfy"/>
             <eStructuralFeatures xmi:type="ecore:EAttribute" xmi:id="_u23Cd6ToEeenne7APpWiQg" name="validatorName" ordered="false">
               <eType xmi:type="ecore:EDataType" href="http://www.eclipse.org/uml2/5.0.0/Types#//String"/>
             </eStructuralFeatures>
@@ -428,8 +413,8 @@
             </eStructuralFeatures>
           </eClassifiers>
           <eClassifiers xmi:type="ecore:EClass" xmi:id="_u23CfKToEeenne7APpWiQg" name="Verify">
-            <eAnnotations xmi:type="ecore:EAnnotation" xmi:id="_u23CfaToEeenne7APpWiQg" source="http://www.eclipse.org/uml2/2.0.0/UML" references="_70Ql8DqPEeCmwNGSFJpOjg"/>
-            <eSuperTypes xmi:type="ecore:EClass" href="http://www.eclipse.org/papyrus/sysml/1.4/SysML#//requirements/Verify"/>
+            <eAnnotations xmi:id="_u23CfaToEeenne7APpWiQg" source="http://www.eclipse.org/uml2/2.0.0/UML" references="_70Ql8DqPEeCmwNGSFJpOjg"/>
+            <eSuperTypes href="http://www.eclipse.org/papyrus/sysml/1.4/SysML#//requirements/Verify"/>
             <eStructuralFeatures xmi:type="ecore:EAttribute" xmi:id="_u23CfqToEeenne7APpWiQg" name="verifierName" ordered="false">
               <eType xmi:type="ecore:EDataType" href="http://www.eclipse.org/uml2/5.0.0/Types#//String"/>
             </eStructuralFeatures>
@@ -442,22 +427,22 @@
           </eClassifiers>
         </contents>
         <contents xmi:type="ecore:EPackage" xmi:id="_4w2NUaROEeeur8HW6jKajg" name="requirementtraceability" nsURI="http://www.eclipse.org/papyrus/requirement/sysml14/0.7.0/PapyrusRE/RequirementTraceability" nsPrefix="RequirementTraceability">
-          <eAnnotations xmi:type="ecore:EAnnotation" xmi:id="_4w2NUqROEeeur8HW6jKajg" source="http://www.eclipse.org/uml2/4.1.0/UML">
+          <eAnnotations xmi:id="_4w2NUqROEeeur8HW6jKajg" source="http://www.eclipse.org/uml2/4.1.0/UML">
             <references xmi:type="ecore:EPackage" href="http://www.eclipse.org/papyrus/sysml/1.4/SysML#//requirements"/>
           </eAnnotations>
-          <eAnnotations xmi:type="ecore:EAnnotation" xmi:id="_4w2NU6ROEeeur8HW6jKajg" source="http://www.eclipse.org/uml2/2.0.0/UML">
-            <details xmi:type="ecore:EStringToStringMapEntry" xmi:id="_4w2NVKROEeeur8HW6jKajg" key="originalName" value="RequirementTraceability"/>
+          <eAnnotations xmi:id="_4w2NU6ROEeeur8HW6jKajg" source="http://www.eclipse.org/uml2/2.0.0/UML">
+            <details xmi:id="_4w2NVKROEeeur8HW6jKajg" key="originalName" value="RequirementTraceability"/>
           </eAnnotations>
-          <eAnnotations xmi:type="ecore:EAnnotation" xmi:id="_4w5QqKROEeeur8HW6jKajg" source="PapyrusVersion">
-            <details xmi:type="ecore:EStringToStringMapEntry" xmi:id="_4w5QqaROEeeur8HW6jKajg" key="Version" value="0.0.1"/>
-            <details xmi:type="ecore:EStringToStringMapEntry" xmi:id="_4w5QqqROEeeur8HW6jKajg" key="Comment" value=""/>
-            <details xmi:type="ecore:EStringToStringMapEntry" xmi:id="_4w5Qq6ROEeeur8HW6jKajg" key="Copyright" value=""/>
-            <details xmi:type="ecore:EStringToStringMapEntry" xmi:id="_4w5QrKROEeeur8HW6jKajg" key="Date" value="2017-09-28"/>
-            <details xmi:type="ecore:EStringToStringMapEntry" xmi:id="_4w5QraROEeeur8HW6jKajg" key="Author" value=""/>
+          <eAnnotations xmi:id="_4w5QqKROEeeur8HW6jKajg" source="PapyrusVersion">
+            <details xmi:id="_4w5QqaROEeeur8HW6jKajg" key="Version" value="0.0.1"/>
+            <details xmi:id="_4w5QqqROEeeur8HW6jKajg" key="Comment" value=""/>
+            <details xmi:id="_4w5Qq6ROEeeur8HW6jKajg" key="Copyright" value=""/>
+            <details xmi:id="_4w5QrKROEeeur8HW6jKajg" key="Date" value="2017-09-28"/>
+            <details xmi:id="_4w5QraROEeeur8HW6jKajg" key="Author" value=""/>
           </eAnnotations>
           <eClassifiers xmi:type="ecore:EClass" xmi:id="_4w2NVaROEeeur8HW6jKajg" name="Satisfy">
-            <eAnnotations xmi:type="ecore:EAnnotation" xmi:id="_4w2NVqROEeeur8HW6jKajg" source="http://www.eclipse.org/uml2/2.0.0/UML" references="_7X8dYDqPEeCmwNGSFJpOjg"/>
-            <eSuperTypes xmi:type="ecore:EClass" href="http://www.eclipse.org/papyrus/sysml/1.4/SysML#//requirements/Satisfy"/>
+            <eAnnotations xmi:id="_4w2NVqROEeeur8HW6jKajg" source="http://www.eclipse.org/uml2/2.0.0/UML" references="_7X8dYDqPEeCmwNGSFJpOjg"/>
+            <eSuperTypes href="http://www.eclipse.org/papyrus/sysml/1.4/SysML#//requirements/Satisfy"/>
             <eStructuralFeatures xmi:type="ecore:EAttribute" xmi:id="_4w2NV6ROEeeur8HW6jKajg" name="validatorName" ordered="false">
               <eType xmi:type="ecore:EDataType" href="http://www.eclipse.org/uml2/5.0.0/Types#//String"/>
             </eStructuralFeatures>
@@ -466,8 +451,8 @@
             </eStructuralFeatures>
           </eClassifiers>
           <eClassifiers xmi:type="ecore:EClass" xmi:id="_4w2NXKROEeeur8HW6jKajg" name="Verify">
-            <eAnnotations xmi:type="ecore:EAnnotation" xmi:id="_4w2NXaROEeeur8HW6jKajg" source="http://www.eclipse.org/uml2/2.0.0/UML" references="_70Ql8DqPEeCmwNGSFJpOjg"/>
-            <eSuperTypes xmi:type="ecore:EClass" href="http://www.eclipse.org/papyrus/sysml/1.4/SysML#//requirements/Verify"/>
+            <eAnnotations xmi:id="_4w2NXaROEeeur8HW6jKajg" source="http://www.eclipse.org/uml2/2.0.0/UML" references="_70Ql8DqPEeCmwNGSFJpOjg"/>
+            <eSuperTypes href="http://www.eclipse.org/papyrus/sysml/1.4/SysML#//requirements/Verify"/>
             <eStructuralFeatures xmi:type="ecore:EAttribute" xmi:id="_4w2NXqROEeeur8HW6jKajg" name="verifierName" ordered="false">
               <eType xmi:type="ecore:EDataType" href="http://www.eclipse.org/uml2/5.0.0/Types#//String"/>
             </eStructuralFeatures>
@@ -481,52 +466,52 @@
         </contents>
       </eAnnotations>
       <packagedElement xmi:type="uml:Stereotype" xmi:id="_7X8dYDqPEeCmwNGSFJpOjg" name="Satisfy">
-        <generalization xmi:type="uml:Generalization" xmi:id="_hq8vAJJWEeesEtnYkurh9A">
+        <generalization xmi:id="_hq8vAJJWEeesEtnYkurh9A">
           <general xmi:type="uml:Stereotype" href="pathmap://SysML14_PROFILES/SysML.profile.uml#SysML.package_packagedElement_Requirements.stereotype_packagedElement_Satisfy"/>
         </generalization>
-        <ownedAttribute xmi:type="uml:Property" xmi:id="_MA7o4DqQEeCmwNGSFJpOjg" name="validatorName" visibility="public">
+        <ownedAttribute xmi:id="_MA7o4DqQEeCmwNGSFJpOjg" name="validatorName" visibility="public">
           <type xmi:type="uml:PrimitiveType" href="pathmap://UML_LIBRARIES/UMLPrimitiveTypes.library.uml#String"/>
           <lowerValue xmi:type="uml:LiteralInteger" xmi:id="_MK6rUDqQEeCmwNGSFJpOjg"/>
           <upperValue xmi:type="uml:LiteralUnlimitedNatural" xmi:id="_MK6rUTqQEeCmwNGSFJpOjg" value="1"/>
         </ownedAttribute>
-        <ownedAttribute xmi:type="uml:Property" xmi:id="_MidBkDqQEeCmwNGSFJpOjg" name="satisfyStatus" visibility="public">
+        <ownedAttribute xmi:id="_MidBkDqQEeCmwNGSFJpOjg" name="satisfyStatus" visibility="public">
           <type xmi:type="uml:Enumeration" href="pathmap://PAPYRUSRE_STANDARDUTILS_MODELLIBARY/PapyrusRE_StandardUtils.modellibrary.uml#_ZnvmUFPKEeCXkoFpHlFAkw"/>
           <lowerValue xmi:type="uml:LiteralInteger" xmi:id="_MsJJEDqQEeCmwNGSFJpOjg"/>
           <upperValue xmi:type="uml:LiteralUnlimitedNatural" xmi:id="_MsJJETqQEeCmwNGSFJpOjg" value="1"/>
         </ownedAttribute>
       </packagedElement>
       <packagedElement xmi:type="uml:Stereotype" xmi:id="_70Ql8DqPEeCmwNGSFJpOjg" name="Verify">
-        <generalization xmi:type="uml:Generalization" xmi:id="_nfLXcJJWEeesEtnYkurh9A">
+        <generalization xmi:id="_nfLXcJJWEeesEtnYkurh9A">
           <general xmi:type="uml:Stereotype" href="pathmap://SysML14_PROFILES/SysML.profile.uml#SysML.package_packagedElement_Requirements.stereotype_packagedElement_Verify"/>
         </generalization>
-        <ownedAttribute xmi:type="uml:Property" xmi:id="_NGXm8DqQEeCmwNGSFJpOjg" name="verifierName" visibility="public">
+        <ownedAttribute xmi:id="_NGXm8DqQEeCmwNGSFJpOjg" name="verifierName" visibility="public">
           <type xmi:type="uml:PrimitiveType" href="pathmap://UML_LIBRARIES/UMLPrimitiveTypes.library.uml#String"/>
           <lowerValue xmi:type="uml:LiteralInteger" xmi:id="_NQWpYDqQEeCmwNGSFJpOjg"/>
           <upperValue xmi:type="uml:LiteralUnlimitedNatural" xmi:id="_NQfzUDqQEeCmwNGSFJpOjg" value="1"/>
         </ownedAttribute>
-        <ownedAttribute xmi:type="uml:Property" xmi:id="_Np1gYDqQEeCmwNGSFJpOjg" name="verifyStatus" visibility="public">
+        <ownedAttribute xmi:id="_Np1gYDqQEeCmwNGSFJpOjg" name="verifyStatus" visibility="public">
           <type xmi:type="uml:Enumeration" href="pathmap://PAPYRUSRE_STANDARDUTILS_MODELLIBARY/PapyrusRE_StandardUtils.modellibrary.uml#_AF-KUFPMEeCXkoFpHlFAkw"/>
           <lowerValue xmi:type="uml:LiteralInteger" xmi:id="_N0aYsDqQEeCmwNGSFJpOjg"/>
           <upperValue xmi:type="uml:LiteralUnlimitedNatural" xmi:id="_N0kJsDqQEeCmwNGSFJpOjg" value="1"/>
         </ownedAttribute>
-        <ownedAttribute xmi:type="uml:Property" xmi:id="_ODdhUDqQEeCmwNGSFJpOjg" name="VV_Method" visibility="public">
+        <ownedAttribute xmi:id="_ODdhUDqQEeCmwNGSFJpOjg" name="VV_Method" visibility="public">
           <type xmi:type="uml:Enumeration" href="pathmap://PAPYRUSRE_STANDARDUTILS_MODELLIBARY/PapyrusRE_StandardUtils.modellibrary.uml#_ZnvmUFPKEeCXkoFpHlFAkw"/>
           <lowerValue xmi:type="uml:LiteralInteger" xmi:id="_OLzlADqQEeCmwNGSFJpOjg"/>
           <upperValue xmi:type="uml:LiteralUnlimitedNatural" xmi:id="_OL9WADqQEeCmwNGSFJpOjg" value="1"/>
         </ownedAttribute>
       </packagedElement>
-      <profileApplication xmi:type="uml:ProfileApplication" xmi:id="_FNW1oKLAEeeYBKEUTtrY-A">
-        <eAnnotations xmi:type="ecore:EAnnotation" xmi:id="_FNXcsKLAEeeYBKEUTtrY-A" source="http://www.eclipse.org/uml2/2.0.0/UML">
+      <profileApplication xmi:id="_FNW1oKLAEeeYBKEUTtrY-A">
+        <eAnnotations xmi:id="_FNXcsKLAEeeYBKEUTtrY-A" source="http://www.eclipse.org/uml2/2.0.0/UML">
           <references xmi:type="ecore:EPackage" href="pathmap://UML_PROFILES/Ecore.profile.uml#_z1OFcHjqEdy8S4Cr8Rc_NA"/>
         </eAnnotations>
-        <appliedProfile xmi:type="uml:Profile" href="pathmap://UML_PROFILES/Ecore.profile.uml#_0"/>
+        <appliedProfile href="pathmap://UML_PROFILES/Ecore.profile.uml#_0"/>
       </profileApplication>
     </packagedElement>
-    <profileApplication xmi:type="uml:ProfileApplication" xmi:id="_WQAlsKK9EeeYBKEUTtrY-A">
-      <eAnnotations xmi:type="ecore:EAnnotation" xmi:id="_WQHTYKK9EeeYBKEUTtrY-A" source="http://www.eclipse.org/uml2/2.0.0/UML">
+    <profileApplication xmi:id="_WQAlsKK9EeeYBKEUTtrY-A">
+      <eAnnotations xmi:id="_WQHTYKK9EeeYBKEUTtrY-A" source="http://www.eclipse.org/uml2/2.0.0/UML">
         <references xmi:type="ecore:EPackage" href="pathmap://UML_PROFILES/Ecore.profile.uml#_z1OFcHjqEdy8S4Cr8Rc_NA"/>
       </eAnnotations>
-      <appliedProfile xmi:type="uml:Profile" href="pathmap://UML_PROFILES/Ecore.profile.uml#_0"/>
+      <appliedProfile href="pathmap://UML_PROFILES/Ecore.profile.uml#_0"/>
     </profileApplication>
   </uml:Profile>
   <Ecore:EPackage xmi:id="_XMFzcKK9EeeYBKEUTtrY-A" base_Package="_wJDIkDp6EeCmwNGSFJpOjg" packageName="papyrusre" nsPrefix="PapyrusRE" nsURI="http://www.eclipse.org/papyrus/requirements/sysml14/0.7.0/PapyrusRE" basePackage="org.eclipse.papyrus.requirements.sysml14" prefix="PapyrusRE"/>
diff --git a/plugins/sysml14/org.eclipse.papyrus.requirements.sysml14.papyrusre/src-gen/org/eclipse/papyrus/requirements/sysml14/papyrusre/Dummy.java b/plugins/sysml14/org.eclipse.papyrus.requirements.sysml14.papyrusre/src-gen/org/eclipse/papyrus/requirements/sysml14/papyrusre/Dummy.java
new file mode 100644
index 0000000..826db63
--- /dev/null
+++ b/plugins/sysml14/org.eclipse.papyrus.requirements.sysml14.papyrusre/src-gen/org/eclipse/papyrus/requirements/sysml14/papyrusre/Dummy.java
@@ -0,0 +1,173 @@
+/**
+ * Copyright (c) 2017 CEA LIST.
+ * 
+ *  All rights reserved. This program and the accompanying materials
+ *  are made available under the terms of the Eclipse Public License v1.0
+ *  which accompanies this distribution, and is available at
+ *  http://www.eclipse.org/legal/epl-v10.html
+ * 
+ * Contributors:
+ *   Sébastien Gerard (CEA LIST) <sebastien.gerard@cea.fr> - Initial API and implementation
+ *   Yupanqui Munoz Julho (CEA LIST) <yupanqui.munozjulho@cea.fr> - Initial API and implementation
+ * 
+ */
+package org.eclipse.papyrus.requirements.sysml14.papyrusre;
+
+import java.util.Arrays;
+import java.util.Collections;
+import java.util.List;
+
+import org.eclipse.emf.common.util.Enumerator;
+
+/**
+ * <!-- begin-user-doc -->
+ * A representation of the literals of the enumeration '<em><b>Dummy</b></em>',
+ * and utility methods for working with them.
+ * <!-- end-user-doc -->
+ * @see org.eclipse.papyrus.requirements.sysml14.papyrusre.PapyrusREPackage#getDummy()
+ * @model
+ * @generated
+ */
+public enum Dummy implements Enumerator {
+	;
+
+	/**
+	 * An array of all the '<em><b>Dummy</b></em>' enumerators.
+	 * <!-- begin-user-doc -->
+	 * <!-- end-user-doc -->
+	 * @generated
+	 */
+	private static final Dummy[] VALUES_ARRAY =
+		new Dummy[] {
+		};
+
+	/**
+	 * A public read-only list of all the '<em><b>Dummy</b></em>' enumerators.
+	 * <!-- begin-user-doc -->
+	 * <!-- end-user-doc -->
+	 * @generated
+	 */
+	public static final List<Dummy> VALUES = Collections.unmodifiableList(Arrays.asList(VALUES_ARRAY));
+
+	/**
+	 * Returns the '<em><b>Dummy</b></em>' literal with the specified literal value.
+	 * <!-- begin-user-doc -->
+	 * <!-- end-user-doc -->
+	 * @param literal the literal.
+	 * @return the matching enumerator or <code>null</code>.
+	 * @generated
+	 */
+	public static Dummy get(String literal) {
+		for (int i = 0; i < VALUES_ARRAY.length; ++i) {
+			Dummy result = VALUES_ARRAY[i];
+			if (result.toString().equals(literal)) {
+				return result;
+			}
+		}
+		return null;
+	}
+
+	/**
+	 * Returns the '<em><b>Dummy</b></em>' literal with the specified name.
+	 * <!-- begin-user-doc -->
+	 * <!-- end-user-doc -->
+	 * @param name the name.
+	 * @return the matching enumerator or <code>null</code>.
+	 * @generated
+	 */
+	public static Dummy getByName(String name) {
+		for (int i = 0; i < VALUES_ARRAY.length; ++i) {
+			Dummy result = VALUES_ARRAY[i];
+			if (result.getName().equals(name)) {
+				return result;
+			}
+		}
+		return null;
+	}
+
+	/**
+	 * Returns the '<em><b>Dummy</b></em>' literal with the specified integer value.
+	 * <!-- begin-user-doc -->
+	 * <!-- end-user-doc -->
+	 * @param value the integer value.
+	 * @return the matching enumerator or <code>null</code>.
+	 * @generated
+	 */
+	public static Dummy get(int value) {
+		switch (value) {
+		}
+		return null;
+	}
+
+	/**
+	 * <!-- begin-user-doc -->
+	 * <!-- end-user-doc -->
+	 * @generated
+	 */
+	private final int value;
+
+	/**
+	 * <!-- begin-user-doc -->
+	 * <!-- end-user-doc -->
+	 * @generated
+	 */
+	private final String name;
+
+	/**
+	 * <!-- begin-user-doc -->
+	 * <!-- end-user-doc -->
+	 * @generated
+	 */
+	private final String literal;
+
+	/**
+	 * Only this class can construct instances.
+	 * <!-- begin-user-doc -->
+	 * <!-- end-user-doc -->
+	 * @generated
+	 */
+	private Dummy(int value, String name, String literal) {
+		this.value = value;
+		this.name = name;
+		this.literal = literal;
+	}
+
+	/**
+	 * <!-- begin-user-doc -->
+	 * <!-- end-user-doc -->
+	 * @generated
+	 */
+	public int getValue() {
+	  return value;
+	}
+
+	/**
+	 * <!-- begin-user-doc -->
+	 * <!-- end-user-doc -->
+	 * @generated
+	 */
+	public String getName() {
+	  return name;
+	}
+
+	/**
+	 * <!-- begin-user-doc -->
+	 * <!-- end-user-doc -->
+	 * @generated
+	 */
+	public String getLiteral() {
+	  return literal;
+	}
+
+	/**
+	 * Returns the literal value of the enumerator, which is its string representation.
+	 * <!-- begin-user-doc -->
+	 * <!-- end-user-doc -->
+	 * @generated
+	 */
+	@Override
+	public String toString() {
+		return literal;
+	}
+	
+} //Dummy
diff --git a/plugins/sysml14/org.eclipse.papyrus.requirements.sysml14.papyrusre/src-gen/org/eclipse/papyrus/requirements/sysml14/papyrusre/PapyrusREFactory.java b/plugins/sysml14/org.eclipse.papyrus.requirements.sysml14.papyrusre/src-gen/org/eclipse/papyrus/requirements/sysml14/papyrusre/PapyrusREFactory.java
new file mode 100644
index 0000000..1dbae02
--- /dev/null
+++ b/plugins/sysml14/org.eclipse.papyrus.requirements.sysml14.papyrusre/src-gen/org/eclipse/papyrus/requirements/sysml14/papyrusre/PapyrusREFactory.java
@@ -0,0 +1,44 @@
+/**
+ * Copyright (c) 2017 CEA LIST.
+ * 
+ *  All rights reserved. This program and the accompanying materials
+ *  are made available under the terms of the Eclipse Public License v1.0
+ *  which accompanies this distribution, and is available at
+ *  http://www.eclipse.org/legal/epl-v10.html
+ * 
+ * Contributors:
+ *   Sébastien Gerard (CEA LIST) <sebastien.gerard@cea.fr> - Initial API and implementation
+ *   Yupanqui Munoz Julho (CEA LIST) <yupanqui.munozjulho@cea.fr> - Initial API and implementation
+ * 
+ */
+package org.eclipse.papyrus.requirements.sysml14.papyrusre;
+
+import org.eclipse.emf.ecore.EFactory;
+
+/**
+ * <!-- begin-user-doc -->
+ * The <b>Factory</b> for the model.
+ * It provides a create method for each non-abstract class of the model.
+ * <!-- end-user-doc -->
+ * @see org.eclipse.papyrus.requirements.sysml14.papyrusre.PapyrusREPackage
+ * @generated
+ */
+public interface PapyrusREFactory extends EFactory {
+	/**
+	 * The singleton instance of the factory.
+	 * <!-- begin-user-doc -->
+	 * <!-- end-user-doc -->
+	 * @generated
+	 */
+	PapyrusREFactory eINSTANCE = org.eclipse.papyrus.requirements.sysml14.papyrusre.impl.PapyrusREFactoryImpl.init();
+
+	/**
+	 * Returns the package supported by this factory.
+	 * <!-- begin-user-doc -->
+	 * <!-- end-user-doc -->
+	 * @return the package supported by this factory.
+	 * @generated
+	 */
+	PapyrusREPackage getPapyrusREPackage();
+
+} //PapyrusREFactory
diff --git a/plugins/sysml14/org.eclipse.papyrus.requirements.sysml14.papyrusre/src-gen/org/eclipse/papyrus/requirements/sysml14/papyrusre/PapyrusREPackage.java b/plugins/sysml14/org.eclipse.papyrus.requirements.sysml14.papyrusre/src-gen/org/eclipse/papyrus/requirements/sysml14/papyrusre/PapyrusREPackage.java
new file mode 100644
index 0000000..1595e86
--- /dev/null
+++ b/plugins/sysml14/org.eclipse.papyrus.requirements.sysml14.papyrusre/src-gen/org/eclipse/papyrus/requirements/sysml14/papyrusre/PapyrusREPackage.java
@@ -0,0 +1,125 @@
+/**
+ * Copyright (c) 2017 CEA LIST.
+ * 
+ *  All rights reserved. This program and the accompanying materials
+ *  are made available under the terms of the Eclipse Public License v1.0
+ *  which accompanies this distribution, and is available at
+ *  http://www.eclipse.org/legal/epl-v10.html
+ * 
+ * Contributors:
+ *   Sébastien Gerard (CEA LIST) <sebastien.gerard@cea.fr> - Initial API and implementation
+ *   Yupanqui Munoz Julho (CEA LIST) <yupanqui.munozjulho@cea.fr> - Initial API and implementation
+ * 
+ */
+package org.eclipse.papyrus.requirements.sysml14.papyrusre;
+
+import org.eclipse.emf.ecore.EEnum;
+import org.eclipse.emf.ecore.EPackage;
+
+/**
+ * <!-- begin-user-doc -->
+ * The <b>Package</b> for the model.
+ * It contains accessors for the meta objects to represent
+ * <ul>
+ *   <li>each class,</li>
+ *   <li>each feature of each class,</li>
+ *   <li>each operation of each class,</li>
+ *   <li>each enum,</li>
+ *   <li>and each data type</li>
+ * </ul>
+ * <!-- end-user-doc -->
+ * @see org.eclipse.papyrus.requirements.sysml14.papyrusre.PapyrusREFactory
+ * @model kind="package"
+ *        annotation="http://www.eclipse.org/uml2/2.0.0/UML originalName='PapyrusRE'"
+ * @generated
+ */
+public interface PapyrusREPackage extends EPackage {
+	/**
+	 * The package name.
+	 * <!-- begin-user-doc -->
+	 * <!-- end-user-doc -->
+	 * @generated
+	 */
+	String eNAME = "papyrusre"; //$NON-NLS-1$
+
+	/**
+	 * The package namespace URI.
+	 * <!-- begin-user-doc -->
+	 * <!-- end-user-doc -->
+	 * @generated
+	 */
+	String eNS_URI = "http://www.eclipse.org/papyrus/requirements/sysml14/0.7.0/PapyrusRE"; //$NON-NLS-1$
+
+	/**
+	 * The package namespace name.
+	 * <!-- begin-user-doc -->
+	 * <!-- end-user-doc -->
+	 * @generated
+	 */
+	String eNS_PREFIX = "PapyrusRE"; //$NON-NLS-1$
+
+	/**
+	 * The singleton instance of the package.
+	 * <!-- begin-user-doc -->
+	 * <!-- end-user-doc -->
+	 * @generated
+	 */
+	PapyrusREPackage eINSTANCE = org.eclipse.papyrus.requirements.sysml14.papyrusre.impl.PapyrusREPackageImpl.init();
+
+	/**
+	 * The meta object id for the '{@link org.eclipse.papyrus.requirements.sysml14.papyrusre.Dummy <em>Dummy</em>}' enum.
+	 * <!-- begin-user-doc -->
+	 * <!-- end-user-doc -->
+	 * @see org.eclipse.papyrus.requirements.sysml14.papyrusre.Dummy
+	 * @see org.eclipse.papyrus.requirements.sysml14.papyrusre.impl.PapyrusREPackageImpl#getDummy()
+	 * @generated
+	 */
+	int DUMMY = 0;
+
+
+	/**
+	 * Returns the meta object for enum '{@link org.eclipse.papyrus.requirements.sysml14.papyrusre.Dummy <em>Dummy</em>}'.
+	 * <!-- begin-user-doc -->
+	 * <!-- end-user-doc -->
+	 * @return the meta object for enum '<em>Dummy</em>'.
+	 * @see org.eclipse.papyrus.requirements.sysml14.papyrusre.Dummy
+	 * @generated
+	 */
+	EEnum getDummy();
+
+	/**
+	 * Returns the factory that creates the instances of the model.
+	 * <!-- begin-user-doc -->
+	 * <!-- end-user-doc -->
+	 * @return the factory that creates the instances of the model.
+	 * @generated
+	 */
+	PapyrusREFactory getPapyrusREFactory();
+
+	/**
+	 * <!-- begin-user-doc -->
+	 * Defines literals for the meta objects that represent
+	 * <ul>
+	 *   <li>each class,</li>
+	 *   <li>each feature of each class,</li>
+	 *   <li>each operation of each class,</li>
+	 *   <li>each enum,</li>
+	 *   <li>and each data type</li>
+	 * </ul>
+	 * <!-- end-user-doc -->
+	 * @generated
+	 */
+	interface Literals {
+		/**
+		 * The meta object literal for the '{@link org.eclipse.papyrus.requirements.sysml14.papyrusre.Dummy <em>Dummy</em>}' enum.
+		 * <!-- begin-user-doc -->
+		 * <!-- end-user-doc -->
+		 * @see org.eclipse.papyrus.requirements.sysml14.papyrusre.Dummy
+		 * @see org.eclipse.papyrus.requirements.sysml14.papyrusre.impl.PapyrusREPackageImpl#getDummy()
+		 * @generated
+		 */
+		EEnum DUMMY = eINSTANCE.getDummy();
+
+	}
+
+} //PapyrusREPackage
diff --git a/plugins/sysml14/org.eclipse.papyrus.requirements.sysml14.papyrusre/src-gen/org/eclipse/papyrus/requirements/sysml14/papyrusre/impl/PapyrusREFactoryImpl.java b/plugins/sysml14/org.eclipse.papyrus.requirements.sysml14.papyrusre/src-gen/org/eclipse/papyrus/requirements/sysml14/papyrusre/impl/PapyrusREFactoryImpl.java
new file mode 100644
index 0000000..76a01b0
--- /dev/null
+++ b/plugins/sysml14/org.eclipse.papyrus.requirements.sysml14.papyrusre/src-gen/org/eclipse/papyrus/requirements/sysml14/papyrusre/impl/PapyrusREFactoryImpl.java
@@ -0,0 +1,146 @@
+/**
+ * Copyright (c) 2017 CEA LIST.
+ * 
+ *  All rights reserved. This program and the accompanying materials
+ *  are made available under the terms of the Eclipse Public License v1.0
+ *  which accompanies this distribution, and is available at
+ *  http://www.eclipse.org/legal/epl-v10.html
+ * 
+ * Contributors:
+ *   Sébastien Gerard (CEA LIST) <sebastien.gerard@cea.fr> - Initial API and implementation
+ *   Yupanqui Munoz Julho (CEA LIST) <yupanqui.munozjulho@cea.fr> - Initial API and implementation
+ * 
+ */
+package org.eclipse.papyrus.requirements.sysml14.papyrusre.impl;
+
+import org.eclipse.emf.ecore.EClass;
+import org.eclipse.emf.ecore.EDataType;
+import org.eclipse.emf.ecore.EObject;
+import org.eclipse.emf.ecore.EPackage;
+
+import org.eclipse.emf.ecore.impl.EFactoryImpl;
+
+import org.eclipse.emf.ecore.plugin.EcorePlugin;
+
+import org.eclipse.papyrus.requirements.sysml14.papyrusre.*;
+
+/**
+ * <!-- begin-user-doc -->
+ * An implementation of the model <b>Factory</b>.
+ * <!-- end-user-doc -->
+ * @generated
+ */
+public class PapyrusREFactoryImpl extends EFactoryImpl implements PapyrusREFactory {
+	/**
+	 * Creates the default factory implementation.
+	 * <!-- begin-user-doc -->
+	 * <!-- end-user-doc -->
+	 * @generated
+	 */
+	public static PapyrusREFactory init() {
+		try {
+			PapyrusREFactory thePapyrusREFactory = (PapyrusREFactory)EPackage.Registry.INSTANCE.getEFactory(PapyrusREPackage.eNS_URI);
+			if (thePapyrusREFactory != null) {
+				return thePapyrusREFactory;
+			}
+		}
+		catch (Exception exception) {
+			EcorePlugin.INSTANCE.log(exception);
+		}
+		return new PapyrusREFactoryImpl();
+	}
+
+	/**
+	 * Creates an instance of the factory.
+	 * <!-- begin-user-doc -->
+	 * <!-- end-user-doc -->
+	 * @generated
+	 */
+	public PapyrusREFactoryImpl() {
+		super();
+	}
+
+	/**
+	 * <!-- begin-user-doc -->
+	 * <!-- end-user-doc -->
+	 * @generated
+	 */
+	@Override
+	public EObject create(EClass eClass) {
+		switch (eClass.getClassifierID()) {
+			default:
+				throw new IllegalArgumentException("The class '" + eClass.getName() + "' is not a valid classifier"); //$NON-NLS-1$ //$NON-NLS-2$
+		}
+	}
+
+	/**
+	 * <!-- begin-user-doc -->
+	 * <!-- end-user-doc -->
+	 * @generated
+	 */
+	@Override
+	public Object createFromString(EDataType eDataType, String initialValue) {
+		switch (eDataType.getClassifierID()) {
+			case PapyrusREPackage.DUMMY:
+				return createDummyFromString(eDataType, initialValue);
+			default:
+				throw new IllegalArgumentException("The datatype '" + eDataType.getName() + "' is not a valid classifier"); //$NON-NLS-1$ //$NON-NLS-2$
+		}
+	}
+
+	/**
+	 * <!-- begin-user-doc -->
+	 * <!-- end-user-doc -->
+	 * @generated
+	 */
+	@Override
+	public String convertToString(EDataType eDataType, Object instanceValue) {
+		switch (eDataType.getClassifierID()) {
+			case PapyrusREPackage.DUMMY:
+				return convertDummyToString(eDataType, instanceValue);
+			default:
+				throw new IllegalArgumentException("The datatype '" + eDataType.getName() + "' is not a valid classifier"); //$NON-NLS-1$ //$NON-NLS-2$
+		}
+	}
+
+	/**
+	 * <!-- begin-user-doc -->
+	 * <!-- end-user-doc -->
+	 * @generated
+	 */
+	public Dummy createDummyFromString(EDataType eDataType, String initialValue) {
+		Dummy result = Dummy.get(initialValue);
+		if (result == null) throw new IllegalArgumentException("The value '" + initialValue + "' is not a valid enumerator of '" + eDataType.getName() + "'"); //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$
+		return result;
+	}
+
+	/**
+	 * <!-- begin-user-doc -->
+	 * <!-- end-user-doc -->
+	 * @generated
+	 */
+	public String convertDummyToString(EDataType eDataType, Object instanceValue) {
+		return instanceValue == null ? null : instanceValue.toString();
+	}
+
+	/**
+	 * <!-- begin-user-doc -->
+	 * <!-- end-user-doc -->
+	 * @generated
+	 */
+	public PapyrusREPackage getPapyrusREPackage() {
+		return (PapyrusREPackage)getEPackage();
+	}
+
+	/**
+	 * <!-- begin-user-doc -->
+	 * <!-- end-user-doc -->
+	 * @deprecated
+	 * @generated
+	 */
+	@Deprecated
+	public static PapyrusREPackage getPackage() {
+		return PapyrusREPackage.eINSTANCE;
+	}
+
+} //PapyrusREFactoryImpl
diff --git a/plugins/sysml14/org.eclipse.papyrus.requirements.sysml14.papyrusre/src-gen/org/eclipse/papyrus/requirements/sysml14/papyrusre/impl/PapyrusREPackageImpl.java b/plugins/sysml14/org.eclipse.papyrus.requirements.sysml14.papyrusre/src-gen/org/eclipse/papyrus/requirements/sysml14/papyrusre/impl/PapyrusREPackageImpl.java
new file mode 100644
index 0000000..6d63a56
--- /dev/null
+++ b/plugins/sysml14/org.eclipse.papyrus.requirements.sysml14.papyrusre/src-gen/org/eclipse/papyrus/requirements/sysml14/papyrusre/impl/PapyrusREPackageImpl.java
@@ -0,0 +1,251 @@
+/**
+ * Copyright (c) 2017 CEA LIST.
+ * 
+ *  All rights reserved. This program and the accompanying materials
+ *  are made available under the terms of the Eclipse Public License v1.0
+ *  which accompanies this distribution, and is available at
+ *  http://www.eclipse.org/legal/epl-v10.html
+ * 
+ * Contributors:
+ *   Sébastien Gerard (CEA LIST) <sebastien.gerard@cea.fr> - Initial API and implementation
+ *   Yupanqui Munoz Julho (CEA LIST) <yupanqui.munozjulho@cea.fr> - Initial API and implementation
+ * 
+ */
+package org.eclipse.papyrus.requirements.sysml14.papyrusre.impl;
+
+import org.eclipse.emf.ecore.EEnum;
+import org.eclipse.emf.ecore.EPackage;
+import org.eclipse.emf.ecore.EcorePackage;
+
+import org.eclipse.emf.ecore.impl.EPackageImpl;
+
+import org.eclipse.papyrus.requirements.sysml14.papyrusre.Dummy;
+import org.eclipse.papyrus.requirements.sysml14.papyrusre.PapyrusREFactory;
+import org.eclipse.papyrus.requirements.sysml14.papyrusre.PapyrusREPackage;
+
+import org.eclipse.papyrus.requirements.sysml14.papyrusre.modellibrary.papyrusrestandardutils.priorityandimportanceconcerns.PriorityAndImportanceConcernsPackage;
+
+import org.eclipse.papyrus.requirements.sysml14.papyrusre.modellibrary.papyrusrestandardutils.requirementandprocessconcerns.RequirementAndProcessConcernsPackage;
+
+import org.eclipse.papyrus.requirements.sysml14.papyrusre.modellibrary.papyrusrestandardutils.requirementclassificationconcerns.RequirementClassificationConcernsPackage;
+
+import org.eclipse.papyrus.requirements.sysml14.papyrusre.modellibrary.papyrusrestandardutils.requirementscharacteristicsconcerns.RequirementsCharacteristicsConcernsPackage;
+
+import org.eclipse.papyrus.requirements.sysml14.papyrusre.modellibrary.papyrusrestandardutils.verificationandvalidationconcerns.VerificationAndValidationConcernsPackage;
+
+import org.eclipse.papyrus.requirements.sysml14.papyrusre.requirementclassification.RequirementClassificationPackage;
+
+import org.eclipse.papyrus.requirements.sysml14.papyrusre.requirementclassification.impl.RequirementClassificationPackageImpl;
+
+import org.eclipse.papyrus.requirements.sysml14.papyrusre.requirementgenericcharacteristics.RequirementGenericCharacteristicsPackage;
+
+import org.eclipse.papyrus.requirements.sysml14.papyrusre.requirementgenericcharacteristics.impl.RequirementGenericCharacteristicsPackageImpl;
+
+import org.eclipse.papyrus.requirements.sysml14.papyrusre.requirementtraceability.RequirementTraceabilityPackage;
+
+import org.eclipse.papyrus.requirements.sysml14.papyrusre.requirementtraceability.impl.RequirementTraceabilityPackageImpl;
+
+import org.eclipse.papyrus.sysml14.sysmlPackage;
+
+import org.eclipse.uml2.types.TypesPackage;
+
+import org.eclipse.uml2.uml.UMLPackage;
+
+/**
+ * <!-- begin-user-doc -->
+ * An implementation of the model <b>Package</b>.
+ * <!-- end-user-doc -->
+ * @generated
+ */
+public class PapyrusREPackageImpl extends EPackageImpl implements PapyrusREPackage {
+	/**
+	 * <!-- begin-user-doc -->
+	 * <!-- end-user-doc -->
+	 * @generated
+	 */
+	private EEnum dummyEEnum = null;
+
+	/**
+	 * Creates an instance of the model <b>Package</b>, registered with
+	 * {@link org.eclipse.emf.ecore.EPackage.Registry EPackage.Registry} by the package
+	 * package URI value.
+	 * <p>Note: the correct way to create the package is via the static
+	 * factory method {@link #init init()}, which also performs
+	 * initialization of the package, or returns the registered package,
+	 * if one already exists.
+	 * <!-- begin-user-doc -->
+	 * <!-- end-user-doc -->
+	 * @see org.eclipse.emf.ecore.EPackage.Registry
+	 * @see org.eclipse.papyrus.requirements.sysml14.papyrusre.PapyrusREPackage#eNS_URI
+	 * @see #init()
+	 * @generated
+	 */
+	private PapyrusREPackageImpl() {
+		super(eNS_URI, PapyrusREFactory.eINSTANCE);
+	}
+
+	/**
+	 * <!-- begin-user-doc -->
+	 * <!-- end-user-doc -->
+	 * @generated
+	 */
+	private static boolean isInited = false;
+
+	/**
+	 * Creates, registers, and initializes the <b>Package</b> for this model, and for any others upon which it depends.
+	 * 
+	 * <p>This method is used to initialize {@link PapyrusREPackage#eINSTANCE} when that field is accessed.
+	 * Clients should not invoke it directly. Instead, they should simply access that field to obtain the package.
+	 * <!-- begin-user-doc -->
+	 * <!-- end-user-doc -->
+	 * @see #eNS_URI
+	 * @see #createPackageContents()
+	 * @see #initializePackageContents()
+	 * @generated
+	 */
+	public static PapyrusREPackage init() {
+		if (isInited) return (PapyrusREPackage)EPackage.Registry.INSTANCE.getEPackage(PapyrusREPackage.eNS_URI);
+
+		// Obtain or create and register package
+		PapyrusREPackageImpl thePapyrusREPackage = (PapyrusREPackageImpl)(EPackage.Registry.INSTANCE.get(eNS_URI) instanceof PapyrusREPackageImpl ? EPackage.Registry.INSTANCE.get(eNS_URI) : new PapyrusREPackageImpl());
+
+		isInited = true;
+
+		// Initialize simple dependencies
+		EcorePackage.eINSTANCE.eClass();
+		RequirementClassificationConcernsPackage.eINSTANCE.eClass();
+		RequirementsCharacteristicsConcernsPackage.eINSTANCE.eClass();
+		PriorityAndImportanceConcernsPackage.eINSTANCE.eClass();
+		RequirementAndProcessConcernsPackage.eINSTANCE.eClass();
+		VerificationAndValidationConcernsPackage.eINSTANCE.eClass();
+		sysmlPackage.eINSTANCE.eClass();
+		TypesPackage.eINSTANCE.eClass();
+		UMLPackage.eINSTANCE.eClass();
+
+		// Obtain or create and register interdependencies
+		RequirementGenericCharacteristicsPackageImpl theRequirementGenericCharacteristicsPackage = (RequirementGenericCharacteristicsPackageImpl)(EPackage.Registry.INSTANCE.getEPackage(RequirementGenericCharacteristicsPackage.eNS_URI) instanceof RequirementGenericCharacteristicsPackageImpl ? EPackage.Registry.INSTANCE.getEPackage(RequirementGenericCharacteristicsPackage.eNS_URI) : RequirementGenericCharacteristicsPackage.eINSTANCE);
+		RequirementClassificationPackageImpl theRequirementClassificationPackage = (RequirementClassificationPackageImpl)(EPackage.Registry.INSTANCE.getEPackage(RequirementClassificationPackage.eNS_URI) instanceof RequirementClassificationPackageImpl ? EPackage.Registry.INSTANCE.getEPackage(RequirementClassificationPackage.eNS_URI) : RequirementClassificationPackage.eINSTANCE);
+		RequirementTraceabilityPackageImpl theRequirementTraceabilityPackage = (RequirementTraceabilityPackageImpl)(EPackage.Registry.INSTANCE.getEPackage(RequirementTraceabilityPackage.eNS_URI) instanceof RequirementTraceabilityPackageImpl ? EPackage.Registry.INSTANCE.getEPackage(RequirementTraceabilityPackage.eNS_URI) : RequirementTraceabilityPackage.eINSTANCE);
+
+		// Create package meta-data objects
+		thePapyrusREPackage.createPackageContents();
+		theRequirementGenericCharacteristicsPackage.createPackageContents();
+		theRequirementClassificationPackage.createPackageContents();
+		theRequirementTraceabilityPackage.createPackageContents();
+
+		// Initialize created meta-data
+		thePapyrusREPackage.initializePackageContents();
+		theRequirementGenericCharacteristicsPackage.initializePackageContents();
+		theRequirementClassificationPackage.initializePackageContents();
+		theRequirementTraceabilityPackage.initializePackageContents();
+
+		// Mark meta-data to indicate it can't be changed
+		thePapyrusREPackage.freeze();
+
+  
+		// Update the registry and return the package
+		EPackage.Registry.INSTANCE.put(PapyrusREPackage.eNS_URI, thePapyrusREPackage);
+		return thePapyrusREPackage;
+	}
+
+	/**
+	 * <!-- begin-user-doc -->
+	 * <!-- end-user-doc -->
+	 * @generated
+	 */
+	public EEnum getDummy() {
+		return dummyEEnum;
+	}
+
+	/**
+	 * <!-- begin-user-doc -->
+	 * <!-- end-user-doc -->
+	 * @generated
+	 */
+	public PapyrusREFactory getPapyrusREFactory() {
+		return (PapyrusREFactory)getEFactoryInstance();
+	}
+
+	/**
+	 * <!-- begin-user-doc -->
+	 * <!-- end-user-doc -->
+	 * @generated
+	 */
+	private boolean isCreated = false;
+
+	/**
+	 * Creates the meta-model objects for the package.  This method is
+	 * guarded to have no affect on any invocation but its first.
+	 * <!-- begin-user-doc -->
+	 * <!-- end-user-doc -->
+	 * @generated
+	 */
+	public void createPackageContents() {
+		if (isCreated) return;
+		isCreated = true;
+
+		// Create enums
+		dummyEEnum = createEEnum(DUMMY);
+	}
+
+	/**
+	 * <!-- begin-user-doc -->
+	 * <!-- end-user-doc -->
+	 * @generated
+	 */
+	private boolean isInitialized = false;
+
+	/**
+	 * Complete the initialization of the package and its meta-model.  This
+	 * method is guarded to have no affect on any invocation but its first.
+	 * <!-- begin-user-doc -->
+	 * <!-- end-user-doc -->
+	 * @generated
+	 */
+	public void initializePackageContents() {
+		if (isInitialized) return;
+		isInitialized = true;
+
+		// Initialize package
+		setName(eNAME);
+		setNsPrefix(eNS_PREFIX);
+		setNsURI(eNS_URI);
+
+		// Obtain other dependent packages
+		RequirementGenericCharacteristicsPackage theRequirementGenericCharacteristicsPackage = (RequirementGenericCharacteristicsPackage)EPackage.Registry.INSTANCE.getEPackage(RequirementGenericCharacteristicsPackage.eNS_URI);
+		RequirementClassificationPackage theRequirementClassificationPackage = (RequirementClassificationPackage)EPackage.Registry.INSTANCE.getEPackage(RequirementClassificationPackage.eNS_URI);
+		RequirementTraceabilityPackage theRequirementTraceabilityPackage = (RequirementTraceabilityPackage)EPackage.Registry.INSTANCE.getEPackage(RequirementTraceabilityPackage.eNS_URI);
+
+		// Add subpackages
+		getESubpackages().add(theRequirementGenericCharacteristicsPackage);
+		getESubpackages().add(theRequirementClassificationPackage);
+		getESubpackages().add(theRequirementTraceabilityPackage);
+
+		// Initialize enums and add enum literals
+		initEEnum(dummyEEnum, Dummy.class, "Dummy"); //$NON-NLS-1$
+
+		// Create resource
+		createResource(eNS_URI);
+
+		// Create annotations
+		// http://www.eclipse.org/uml2/2.0.0/UML
+		createUMLAnnotations();
+	}
+
+	/**
+	 * Initializes the annotations for <b>http://www.eclipse.org/uml2/2.0.0/UML</b>.
+	 * <!-- begin-user-doc -->
+	 * <!-- end-user-doc -->
+	 * @generated
+	 */
+	protected void createUMLAnnotations() {
+		String source = "http://www.eclipse.org/uml2/2.0.0/UML"; //$NON-NLS-1$	
+		addAnnotation
+		  (this, 
+		   source, 
+		   new String[] {
+			 "originalName", "PapyrusRE" //$NON-NLS-1$ //$NON-NLS-2$
+		   });
+	}
+
+} //PapyrusREPackageImpl
diff --git a/plugins/sysml14/org.eclipse.papyrus.requirements.sysml14.papyrusre/src-gen/org/eclipse/papyrus/requirements/sysml14/papyrusre/requirementclassification/impl/RequirementClassificationPackageImpl.java b/plugins/sysml14/org.eclipse.papyrus.requirements.sysml14.papyrusre/src-gen/org/eclipse/papyrus/requirements/sysml14/papyrusre/requirementclassification/impl/RequirementClassificationPackageImpl.java
index 706f13c..de990a1 100644
--- a/plugins/sysml14/org.eclipse.papyrus.requirements.sysml14.papyrusre/src-gen/org/eclipse/papyrus/requirements/sysml14/papyrusre/requirementclassification/impl/RequirementClassificationPackageImpl.java
+++ b/plugins/sysml14/org.eclipse.papyrus.requirements.sysml14.papyrusre/src-gen/org/eclipse/papyrus/requirements/sysml14/papyrusre/requirementclassification/impl/RequirementClassificationPackageImpl.java
@@ -19,7 +19,6 @@
 import org.eclipse.emf.ecore.EcorePackage;
 
 import org.eclipse.emf.ecore.impl.EPackageImpl;
-
 import org.eclipse.papyrus.requirements.sysml14.papyrusre.modellibrary.papyrusrestandardutils.priorityandimportanceconcerns.PriorityAndImportanceConcernsPackage;
 
 import org.eclipse.papyrus.requirements.sysml14.papyrusre.modellibrary.papyrusrestandardutils.requirementandprocessconcerns.RequirementAndProcessConcernsPackage;
diff --git a/plugins/sysml14/org.eclipse.papyrus.requirements.sysml14.papyrusre/src-gen/org/eclipse/papyrus/requirements/sysml14/papyrusre/requirementgenericcharacteristics/impl/RequirementGenericCharacteristicsPackageImpl.java b/plugins/sysml14/org.eclipse.papyrus.requirements.sysml14.papyrusre/src-gen/org/eclipse/papyrus/requirements/sysml14/papyrusre/requirementgenericcharacteristics/impl/RequirementGenericCharacteristicsPackageImpl.java
index 3dca11c..024fce9 100644
--- a/plugins/sysml14/org.eclipse.papyrus.requirements.sysml14.papyrusre/src-gen/org/eclipse/papyrus/requirements/sysml14/papyrusre/requirementgenericcharacteristics/impl/RequirementGenericCharacteristicsPackageImpl.java
+++ b/plugins/sysml14/org.eclipse.papyrus.requirements.sysml14.papyrusre/src-gen/org/eclipse/papyrus/requirements/sysml14/papyrusre/requirementgenericcharacteristics/impl/RequirementGenericCharacteristicsPackageImpl.java
@@ -19,7 +19,6 @@
 import org.eclipse.emf.ecore.EcorePackage;
 
 import org.eclipse.emf.ecore.impl.EPackageImpl;
-
 import org.eclipse.papyrus.requirements.sysml14.papyrusre.modellibrary.papyrusrestandardutils.priorityandimportanceconcerns.PriorityAndImportanceConcernsPackage;
 
 import org.eclipse.papyrus.requirements.sysml14.papyrusre.modellibrary.papyrusrestandardutils.requirementandprocessconcerns.RequirementAndProcessConcernsPackage;
diff --git a/plugins/sysml14/org.eclipse.papyrus.requirements.sysml14.papyrusre/src-gen/org/eclipse/papyrus/requirements/sysml14/papyrusre/requirementgenericcharacteristics/impl/RequirementImpl.java b/plugins/sysml14/org.eclipse.papyrus.requirements.sysml14.papyrusre/src-gen/org/eclipse/papyrus/requirements/sysml14/papyrusre/requirementgenericcharacteristics/impl/RequirementImpl.java
index 56ce41a..723ea92 100644
--- a/plugins/sysml14/org.eclipse.papyrus.requirements.sysml14.papyrusre/src-gen/org/eclipse/papyrus/requirements/sysml14/papyrusre/requirementgenericcharacteristics/impl/RequirementImpl.java
+++ b/plugins/sysml14/org.eclipse.papyrus.requirements.sysml14.papyrusre/src-gen/org/eclipse/papyrus/requirements/sysml14/papyrusre/requirementgenericcharacteristics/impl/RequirementImpl.java
@@ -78,7 +78,7 @@
 	 * @generated
 	 * @ordered
 	 */
-	protected static final AgreementStatusKind AGREEMENT_STATUS_EDEFAULT = AgreementStatusKind.PROPOSED;
+	protected static final AgreementStatusKind AGREEMENT_STATUS_EDEFAULT = AgreementStatusKind.SUBMITTED;
 
 	/**
 	 * The cached value of the '{@link #getAgreementStatus() <em>Agreement Status</em>}' attribute.
diff --git a/plugins/sysml14/org.eclipse.papyrus.requirements.sysml14.papyrusre/src-gen/org/eclipse/papyrus/requirements/sysml14/papyrusre/requirementtraceability/impl/RequirementTraceabilityPackageImpl.java b/plugins/sysml14/org.eclipse.papyrus.requirements.sysml14.papyrusre/src-gen/org/eclipse/papyrus/requirements/sysml14/papyrusre/requirementtraceability/impl/RequirementTraceabilityPackageImpl.java
index a120544..3ccf23a 100644
--- a/plugins/sysml14/org.eclipse.papyrus.requirements.sysml14.papyrusre/src-gen/org/eclipse/papyrus/requirements/sysml14/papyrusre/requirementtraceability/impl/RequirementTraceabilityPackageImpl.java
+++ b/plugins/sysml14/org.eclipse.papyrus.requirements.sysml14.papyrusre/src-gen/org/eclipse/papyrus/requirements/sysml14/papyrusre/requirementtraceability/impl/RequirementTraceabilityPackageImpl.java
@@ -19,7 +19,6 @@
 import org.eclipse.emf.ecore.EcorePackage;
 
 import org.eclipse.emf.ecore.impl.EPackageImpl;
-
 import org.eclipse.papyrus.requirements.sysml14.papyrusre.modellibrary.papyrusrestandardutils.priorityandimportanceconcerns.PriorityAndImportanceConcernsPackage;
 
 import org.eclipse.papyrus.requirements.sysml14.papyrusre.modellibrary.papyrusrestandardutils.requirementandprocessconcerns.RequirementAndProcessConcernsPackage;
diff --git a/plugins/sysml14/org.eclipse.papyrus.requirements.sysml14.papyrusre.modellibrary/src-gen/org/eclipse/papyrus/requirements/sysml14/papyrusre/modellibrary/papyrusrestandardutils/requirementandprocessconcerns/AgreementStatusKind.java b/plugins/sysml14/org.eclipse.papyrus.requirements.sysml14.papyrusre.modellibrary/src-gen/org/eclipse/papyrus/requirements/sysml14/papyrusre/modellibrary/papyrusrestandardutils/requirementandprocessconcerns/AgreementStatusKind.java
index 0e80978..948757a 100644
--- a/plugins/sysml14/org.eclipse.papyrus.requirements.sysml14.papyrusre.modellibrary/src-gen/org/eclipse/papyrus/requirements/sysml14/papyrusre/modellibrary/papyrusrestandardutils/requirementandprocessconcerns/AgreementStatusKind.java
+++ b/plugins/sysml14/org.eclipse.papyrus.requirements.sysml14.papyrusre.modellibrary/src-gen/org/eclipse/papyrus/requirements/sysml14/papyrusre/modellibrary/papyrusrestandardutils/requirementandprocessconcerns/AgreementStatusKind.java
@@ -30,14 +30,14 @@
  */
 public enum AgreementStatusKind implements Enumerator {
 	/**
 	 * The '<em><b>Proposed</b></em>' literal object.
 	 * <!-- begin-user-doc -->
 	 * <!-- end-user-doc -->
-	 * @see #PROPOSED_VALUE
+	 * @see #SUBMITTED_VALUE
 	 * @generated
 	 * @ordered
 	 */
-	PROPOSED(0, "Proposed", "Proposed"), //$NON-NLS-1$ //$NON-NLS-2$
+	SUBMITTED(0, "Submitted", "Submitted"), //$NON-NLS-1$ //$NON-NLS-2$
 
 	/**
 	 * The '<em><b>To Be Refined</b></em>' literal object.
@@ -80,19 +80,19 @@
 	REJECTED(4, "Rejected", "Rejected"); //$NON-NLS-1$ //$NON-NLS-2$
 
 	/**
 	 * The '<em><b>Proposed</b></em>' literal value.
 	 * <!-- begin-user-doc -->
 	 * <p>
 	 * If the meaning of '<em><b>Proposed</b></em>' literal object isn't clear,
 	 * there really should be more of a description here...
 	 * </p>
 	 * <!-- end-user-doc -->
-	 * @see #PROPOSED
-	 * @model name="Proposed"
+	 * @see #SUBMITTED
+	 * @model name="Submitted"
 	 * @generated
 	 * @ordered
 	 */
-	public static final int PROPOSED_VALUE = 0;
+	public static final int SUBMITTED_VALUE = 0;
 
 	/**
 	 * The '<em><b>To Be Refined</b></em>' literal value.
@@ -162,7 +162,7 @@
 	 */
 	private static final AgreementStatusKind[] VALUES_ARRAY =
 		new AgreementStatusKind[] {
-			PROPOSED,
+			SUBMITTED,
 			TO_BE_REFINED,
 			ACCEPTED,
 			DRAFT,
@@ -223,7 +223,7 @@
 	 */
 	public static AgreementStatusKind get(int value) {
 		switch (value) {
-			case PROPOSED_VALUE: return PROPOSED;
+			case SUBMITTED_VALUE: return SUBMITTED;
 			case TO_BE_REFINED_VALUE: return TO_BE_REFINED;
 			case ACCEPTED_VALUE: return ACCEPTED;
 			case DRAFT_VALUE: return DRAFT;
@@ -30,14 +30,14 @@
 public enum AgreementStatusKind implements Enumerator {
 	/**
-	 * The '<em><b>Proposed</b></em>' literal object.
+	 * The '<em><b>Submitted</b></em>' literal object.
 	 * <!-- begin-user-doc -->
 	 * <!-- end-user-doc -->
@@ -80,19 +80,19 @@
 
 	/**
-	 * The '<em><b>Proposed</b></em>' literal value.
+	 * The '<em><b>Submitted</b></em>' literal value.
 	 * <!-- begin-user-doc -->
 	 * <p>
@@ -80,19 +80,19 @@
 	 * <!-- begin-user-doc -->
 	 * <p>
-	 * If the meaning of '<em><b>Proposed</b></em>' literal object isn't clear,
+	 * If the meaning of '<em><b>Submitted</b></em>' literal object isn't clear,
 	 * there really should be more of a description here...
 	 * </p>